@@ -1,17 +1,18 @@
  /*
  * Project       : ipv6calc
  * File          : db_cc_reg_assignment.h
- * Version       : $Id: db_cc_reg_assignment.h,v 1.1 2013/10/13 16:19:34 ds6peter Exp $
- * Generated     : Sun Oct 13 07:48:55 2013
+ * Version       : $Id: db_cc_reg_assignment.h,v 1.7 2014/05/16 20:34:02 ds6peter Exp $
+ * Generated     : Fri May 16 22:23:24 2014
  * Data copyright: RIPE NCC, APNIC, ARIN, LACNIC, AFRINIC
  *
  * Information:
  *  Additional header file for databases/lib/libipv6calc_db_wrapper_BuiltIn.c
  */
 
-static const char *db_cc_registry_status = "AFRINIC/20130806 APNIC/20130805 ARIN/20130805 LACNIC/20130805 RIPENCC/20130805";
+static const char *db_cc_registry_status = "AFRINIC/20140516 APNIC/20140516 ARIN/20140516 LACNIC/20140515 RIPENCC/20140515";
 
 static const s_cc_reg_assignment cc_reg_assignment[] = {
+	{ "", REGISTRY_ARIN     },
 	{ "AD", REGISTRY_RIPE     },
 	{ "AE", REGISTRY_RIPE     },
 	{ "AF", REGISTRY_APNIC    },
@@ -220,7 +221,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "TG", REGISTRY_AFRINIC  },
 	{ "TH", REGISTRY_APNIC    },
 	{ "TJ", REGISTRY_RIPE     },
-	{ "TK", REGISTRY_RIPE     },
+	{ "TK", REGISTRY_APNIC    },
 	{ "TL", REGISTRY_APNIC    },
 	{ "TM", REGISTRY_RIPE     },
 	{ "TN", REGISTRY_AFRINIC  },
@@ -232,7 +233,6 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "TZ", REGISTRY_AFRINIC  },
 	{ "UA", REGISTRY_RIPE     },
 	{ "UG", REGISTRY_AFRINIC  },
-	{ "UM", REGISTRY_ARIN     },
 	{ "US", REGISTRY_ARIN     },
 	{ "UY", REGISTRY_LACNIC   },
 	{ "UZ", REGISTRY_RIPE     },
@@ -246,6 +246,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "WF", REGISTRY_APNIC    },
 	{ "WS", REGISTRY_APNIC    },
 	{ "YE", REGISTRY_RIPE     },
+	{ "YT", REGISTRY_AFRINIC  },
 	{ "ZA", REGISTRY_AFRINIC  },
 	{ "ZM", REGISTRY_AFRINIC  },
 	{ "ZW", REGISTRY_AFRINIC  },
@@ -791,7 +792,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  536  QK
 	{ REGISTRY_UNKNOWN  }, //  537  RK
 	{ REGISTRY_RIPE     }, //  538  SK
-	{ REGISTRY_RIPE     }, //  539  TK
+	{ REGISTRY_APNIC    }, //  539  TK
 	{ REGISTRY_UNKNOWN  }, //  540  UK
 	{ REGISTRY_UNKNOWN  }, //  541  VK
 	{ REGISTRY_UNKNOWN  }, //  542  WK
@@ -844,7 +845,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  589  RM
 	{ REGISTRY_RIPE     }, //  590  SM
 	{ REGISTRY_RIPE     }, //  591  TM
-	{ REGISTRY_ARIN     }, //  592  UM
+	{ REGISTRY_UNKNOWN  }, //  592  UM
 	{ REGISTRY_UNKNOWN  }, //  593  VM
 	{ REGISTRY_UNKNOWN  }, //  594  WM
 	{ REGISTRY_UNKNOWN  }, //  595  XM
@@ -1030,7 +1031,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  775  VT
 	{ REGISTRY_UNKNOWN  }, //  776  WT
 	{ REGISTRY_UNKNOWN  }, //  777  XT
-	{ REGISTRY_UNKNOWN  }, //  778  YT
+	{ REGISTRY_AFRINIC  }, //  778  YT
 	{ REGISTRY_UNKNOWN  }, //  779  ZT
 	{ REGISTRY_APNIC    }, //  780  AU
 	{ REGISTRY_UNKNOWN  }, //  781  BU
@@ -1276,4 +1277,4 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, // 1021  reserved-special
 	{ REGISTRY_UNKNOWN  }, // 1022  reserved-special
 	{ REGISTRY_UNKNOWN  }, // 1023  reserved-special
-};
+};
\ No newline at end of file
