@@ -2,9 +2,9 @@
 #
 # Project    : ipv6calc/databases/ipv6-assignment
 # File       : create-registry-list.pl
-# Version    : $Id: create-registry-list.pl,v 1.9 2013/10/15 06:21:42 ds6peter Exp $
+# Version    : $Id: create-registry-list.pl,v 1.11 2014/02/28 06:46:36 ds6peter Exp $
 # Copyright  : 2005 by Simon Arlott (initial implementation of global file only)
-#              2005-2013 by Peter Bieringer <pb (at) bieringer.de> (further extensions)
+#              2005-2014 by Peter Bieringer <pb (at) bieringer.de> (further extensions)
 # License    : GNU GPL v2
 #
 # Information:
@@ -17,13 +17,17 @@ use Net::IP;
 use Math::BigInt;
 use XML::Simple;
 
-my $debug = (0xffff &  ~(0x10 | 0x20 | 0x100 | 0x40));
+my $debug = 0;
+
 # Debugging
-#  0x0010: proceed registry files
+#$debug |= 0x0010; #  0x0010: proceed registry files
 #  0x0020: proceed global file
 #  0x0040: fill data
 #  0x0100: subnet mask generation
 
+# $debug |= 0x0200; # parse lines
+$debug |= 0x0400; # store
+
 my $OUTFILE = "dbipv6addr_assignment.h";
 
 my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time - 48*60*60);
@@ -137,6 +141,8 @@ proceed_global();
 foreach my $file (@files) {
 	print "Proceed file: " . $file . "\n";
 
+	my $counter = 0;
+
 	open(FILE, "<$file") || die "Cannot open file: $file";
 
 	my $line;
@@ -148,6 +154,8 @@ foreach my $file (@files) {
 		$line = $_;
 		chomp $line;
 
+		$counter++;
+
 		# catch date line
 		if ($line =~ /^2(\.[0-9])?\|([^\|]+)\|.*\|([0-9]{8})\|[^\|]*$/o) {
 			$date_created{uc($2)} = $3;
@@ -160,7 +168,7 @@ foreach my $file (@files) {
 		if ( ! ( $line =~ /\|ipv6\|/ ) ) { next; };
 		if ( $line =~ /\|\*\|/ ) { next; };
 
-		#print $line . "\n";
+		print $line . "\n" if ($debug & 0x0200);
 
 		my ($reg, $tld, $token, $ipv6, $prefixlen, $date, $status, $other) = split /\|/, $line;
 
@@ -188,7 +196,7 @@ foreach my $file (@files) {
 			die "Unsupported registry: " . $reg;
 		};
 
-		print "reg=" . $reg . " ipv6=" . $ipv6 . "/" . $prefixlen . "\n" if ($debug & 0x10);
+		print "check: reg=" . $reg . " ipv6=" . $ipv6 . "/" . $prefixlen . "\n" if ($debug & 0x10);
 
 		# Check for already included in range:
 		my $ip_ipv6 = new Net::IP($ipv6) || die "Can't create IPv6 object from ipv6=$ipv6";
@@ -200,7 +208,7 @@ Label_restart:
 		for (my $i = 0; $i < scalar(@$parray); $i++) {
 			my $ipv6_check = $$parray[$i];
 
-			print " check against ipv6=" . $ipv6_check if ($debug & 0x10);
+			print "check: check against ipv6=" . $ipv6_check if ($debug & 0x10);
 
 			if (defined $cache{$ipv6_check}) {
 				$ip_ipv6_check = $cache{$ipv6_check};
@@ -237,6 +245,8 @@ Label_restart:
 			die "Currently unsupported prefix length (>64): $ipv6/$prefixlen";
 		};
 
+		print "store: reg=" . $reg . " ipv6=" . $ipv6 . "/" . $prefixlen . "\n" if ($debug & 0x0400);
+
 		# Push into array
 		push @$parray, $ipv6 . "/" . $prefixlen;
 	};
@@ -318,9 +328,11 @@ print OUT qq| * Generated     : $now_string
  * Data copyright: IANA ARIN RIPENCC APNIC LACNIC AFRINIC
  *
  * Information:
- *  Additional header file for libipv6addr.c
+ *  Additional header file for databases/lib/libipv6calc_db_wrapper_BuiltIn.c
  */
 
+#include "databases/lib/libipv6calc_db_wrapper_BuiltIn.h"
+
 |;
 
 # print creation dates
@@ -340,7 +352,7 @@ static const s_ipv6addr_assignment dbipv6addr_assignment[] = {
 
 
 foreach my $ipv6 (sort keys %data) {
-	printf OUT "\t{ 0x%s, 0x%s, 0x%s, 0x%s, %3d, \"%s\" },\n", $data{$ipv6}->{'ipv6_00_31'}, $data{$ipv6}->{'ipv6_32_63'}, $data{$ipv6}->{'mask_00_31'}, $data{$ipv6}->{'mask_32_63'}, $data{$ipv6}->{'mask_length'}, $data{$ipv6}->{'reg'};
+	printf OUT "\t{ 0x%s, 0x%s, 0x%s, 0x%s, %3d, REGISTRY_%-10s },\n", $data{$ipv6}->{'ipv6_00_31'}, $data{$ipv6}->{'ipv6_32_63'}, $data{$ipv6}->{'mask_00_31'}, $data{$ipv6}->{'mask_32_63'}, $data{$ipv6}->{'mask_length'}, $data{$ipv6}->{'reg'};
 };
 
 print OUT qq|};
