@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper.h
- * Version    : $Id: libipv6calc_db_wrapper.h,v 1.17 2013/10/13 16:18:44 ds6peter Exp $
- * Copyright  : 2013-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: libipv6calc_db_wrapper.h,v 1.21 2014/05/11 09:49:38 ds6peter Exp $
+ * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper.c
@@ -13,6 +13,9 @@
 #define _libipv6calc_db_wrapper_h 1
 
 #include "ipv6calctypes.h"
+#include "libmac.h"
+#include "libipv4addr.h"
+#include "libipv6addr.h"
 
 extern uint32_t wrapper_features;
 
@@ -61,8 +64,11 @@ static const s_type ipv6calc_db_features[] = {
 #define COUNTRYCODE_LETTER1_MAX          26     // A-Z
 #define COUNTRYCODE_LETTER2_MAX          36     // 0-9A-Z
 #define COUNTRYCODE_INDEX_LETTER_MAX     (COUNTRYCODE_LETTER1_MAX * COUNTRYCODE_LETTER2_MAX - 1)
-#define COUNTRYCODE_INDEX_MAX            1023
-#define COUNTRYCODE_INDEX_UNKNOWN        1022
+#define COUNTRYCODE_INDEX_MAX            1023	// 0x3ff
+#define COUNTRYCODE_INDEX_UNKNOWN        1022	// 0x3fe
+
+#define COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MAX   (COUNTRYCODE_INDEX_UNKNOWN - 1)
+#define COUNTRYCODE_INDEX_UNKNOWN_REGISTRY_MAP_MIN   (COUNTRYCODE_INDEX_UNKNOWN - 16)
 
 // macros for mapping index to chars and vice-versa
 #define COUNTRYCODE_INDEX_TO_CHAR1(index)  ((index % COUNTRYCODE_LETTER1_MAX) + 'A')
@@ -98,3 +104,15 @@ extern uint32_t    libipv6calc_db_wrapper_as_num32_decomp17(const uint32_t as_nu
 // Registries
 extern int         libipv6calc_db_wrapper_registry_num_by_as_num32(const uint32_t as_num32);
 extern int         libipv6calc_db_wrapper_registry_num_by_cc_index(const uint16_t cc_index);
+
+// IEEE
+extern int libipv6calc_db_wrapper_ieee_vendor_string_by_macaddr(char *resultstring, const size_t resultstring_length, const ipv6calc_macaddr *macaddrp);
+extern int libipv6calc_db_wrapper_ieee_vendor_string_short_by_macaddr(char *resultstring, const size_t resultstring_length, const ipv6calc_macaddr *macaddrp);
+
+// IPv4 Registry
+extern int libipv6calc_db_wrapper_registry_string_by_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, char *resultstring, const size_t resultstring_length);
+extern int libipv6calc_db_wrapper_registry_num_by_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp);
+
+// IPv6 Registry
+extern int libipv6calc_db_wrapper_registry_string_by_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const size_t resultstring_length);
+extern int libipv6calc_db_wrapper_registry_num_by_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp);
