@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_IP2Location.c
- * Version    : $Id: libipv6calc_db_wrapper_IP2Location.c,v 1.12 2013/11/03 18:21:46 ds6peter Exp $
- * Copyright  : 2013-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: libipv6calc_db_wrapper_IP2Location.c,v 1.16 2014/05/16 20:34:02 ds6peter Exp $
+ * Copyright  : 2013-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc IP2Location database wrapper
@@ -103,7 +103,7 @@ const char **libipv6calc_db_wrapper_IP2LocationDBDescription = NULL;
 static uint32_t ip2location_db_usage_map[IP2LOCATION_DB_MAX_BLOCKS_32];
 
 #define IP2LOCATION_DB_USAGE_MAP_TAG(db)	if (db < (32 * IP2LOCATION_DB_MAX_BLOCKS_32)) { \
-							DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper_IP2Location, "Tag usage for db: %d", db); \
+							DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "Tag usage for db: %d", db); \
 							ip2location_db_usage_map[db / 32] |= 1 << (db % 32); \
 						} else { \
 							fprintf(stderr, "FIXME: unsupported db value (exceed limit): %d (%d)\n", db, 32 * IP2LOCATION_DB_MAX_BLOCKS_32 - 1); \
@@ -126,10 +126,10 @@ static char     *libipv6calc_db_wrapper_IP2Location_dbfilename(int type);
 int libipv6calc_db_wrapper_IP2Location_wrapper_init(void) {
 	int i;
 
-	DEBUGPRINT_NA(DEBUG_libipv6addr_db_wrapper, "Called");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Called");
 
 #ifdef SUPPORT_IP2LOCATION_DYN
-	DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Load library: %s", ip2location_lib_file);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Load library: %s", ip2location_lib_file);
 
 	dl_IP2Location_handle = dlopen(ip2location_lib_file, RTLD_NOW | RTLD_LOCAL);
 
@@ -138,7 +138,7 @@ int libipv6calc_db_wrapper_IP2Location_wrapper_init(void) {
 		return(1);
 	};
 
-	DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Loaded library successful: %s", ip2location_lib_file);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Loaded library successful: %s", ip2location_lib_file);
 #else
 	// nothing to set for the moment
 #endif
@@ -149,18 +149,18 @@ int libipv6calc_db_wrapper_IP2Location_wrapper_init(void) {
 	// nothing to set for the moment
 #endif
 
-	DEBUGPRINT_NA(DEBUG_libipv6addr_db_wrapper, "Check for standard IP2Location databases");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Check for standard IP2Location databases");
 
 	/* check available databases for resolution */
 	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_IP2Location_db_file_desc); i++) {
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "IP2Location database test for availability: %s", libipv6calc_db_wrapper_IP2Location_db_file_desc[i].filename);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "IP2Location database test for availability: %s", libipv6calc_db_wrapper_IP2Location_db_file_desc[i].filename);
 		if (libipv6calc_db_wrapper_IP2Location_db_avail(libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number) == 1) {
-			DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "IP2Location database available: %s", libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "IP2Location database available: %s", libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
 			wrapper_features_IP2Location |= libipv6calc_db_wrapper_IP2Location_db_file_desc[i].feature;
 		};
 	};
 
-	DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Version of linked library: %s / IPv6 support: %s / custom directory: %s", libipv6calc_db_wrapper_IP2Location_lib_version(), libipv6calc_db_wrapper_IP2Location_IPv6_support[wrapper_ip2location_ipv6_support].token, ip2location_db_dir);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Version of linked library: %s / IPv6 support: %s / custom directory: %s", libipv6calc_db_wrapper_IP2Location_lib_version(), libipv6calc_db_wrapper_IP2Location_IPv6_support[wrapper_ip2location_ipv6_support].token, ip2location_db_dir);
 
 	wrapper_features |= wrapper_features_IP2Location;
 
@@ -175,9 +175,7 @@ int libipv6calc_db_wrapper_IP2Location_wrapper_init(void) {
  * out: 0=ok, 1=error
  */
 int libipv6calc_db_wrapper_IP2Location_wrapper_cleanup(void) {
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called\n", __FILE__, __func__);
-	};
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Called");
 
 #ifdef SUPPORT_IP2LOCATION
 	// no general cleanup provided
@@ -185,9 +183,7 @@ int libipv6calc_db_wrapper_IP2Location_wrapper_cleanup(void) {
 
 	dl_IP2Location_handle = NULL; // disable handle
 
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Finished\n", __FILE__, __func__);
-	};
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Finished");
 	return 0;
 };
 
@@ -199,9 +195,7 @@ int libipv6calc_db_wrapper_IP2Location_wrapper_cleanup(void) {
  * out: modified string;
  */
 void libipv6calc_db_wrapper_IP2Location_wrapper_info(char* string, const size_t size) {
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called\n", __FILE__, __func__);
-	};
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Called");
 
 #ifdef SUPPORT_IP2LOCATION
 	snprintf(string, size, "IP2Location available databases: Country4=%d Country6=%d ASN4=%d ASN6=%d City4=%d City6=%d", ip2location_country_v4, ip2location_country_v6, ip2location_asnum_v4, ip2location_asnum_v6, ip2location_city_v4, ip2location_city_v6);
@@ -209,7 +203,7 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_info(char* string, const size_t
 	snprintf(string, size, "No IP2Location support built-in");
 #endif
 
-	DEBUGPRINT_NA(DEBUG_libipv6addr_db_wrapper, "Finished");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Finished");
 	return;
 };
 
@@ -228,7 +222,7 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_print_db_info(const int level_ve
 		prefix = prefix_string;
 	};
 
-	DEBUGPRINT_NA(DEBUG_libipv6addr_db_wrapper, "Called");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Called");
 
 	printf("%sIP2Location: features: 0x%08x\n", prefix, wrapper_features_IP2Location);
 
@@ -240,12 +234,12 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_print_db_info(const int level_ve
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 		if (dl_IP2Location_handle == NULL) {
-			DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Check whether db file exists: %s", libipv6calc_db_wrapper_IP2Location_dbfilename(type));
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Check whether db file exists: %s", libipv6calc_db_wrapper_IP2Location_dbfilename(type));
 			if (access(libipv6calc_db_wrapper_IP2Location_dbfilename(type), R_OK) == 0) {
-				DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "DB file exists: %s", libipv6calc_db_wrapper_IP2Location_dbfilename(type));
+				DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "DB file exists: %s", libipv6calc_db_wrapper_IP2Location_dbfilename(type));
 				printf("%sIP2Location: %-27s: %-40s (LIBRARY-NOT-LOADED)\n", prefix, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description, libipv6calc_db_wrapper_IP2Location_dbfilename(type));
 			} else {
-				DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "DB file doesn't exist or can't open: %s (%s)", libipv6calc_db_wrapper_IP2Location_dbfilename(type), strerror(errno));
+				DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "DB file doesn't exist or can't open: %s (%s)", libipv6calc_db_wrapper_IP2Location_dbfilename(type), strerror(errno));
 				if (level_verbose == LEVEL_VERBOSE2) {
 					printf("%sIP2Location: %-27s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description, libipv6calc_db_wrapper_IP2Location_dbfilename(type), strerror(errno));
 				};
@@ -280,7 +274,7 @@ void libipv6calc_db_wrapper_IP2Location_wrapper_print_db_info(const int level_ve
 	snprintf(string, size, "%sNo IP2Location support built-in", prefix);
 #endif // SUPPORT_IP2LOCATION
 
-	DEBUGPRINT_NA(DEBUG_libipv6addr_db_wrapper, "Finished");
+	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Finished");
 	return;
 };
 
@@ -296,7 +290,7 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_db_info_used(void) {
 
 	for (db = 0; db < 32 * IP2LOCATION_DB_MAX_BLOCKS_32; db++) {
 		if ((ip2location_db_usage_map[db / 32] & (1 << (db % 32))) != 0) {
-			DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper_IP2Location, "DB used: %d", db);
+			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_IP2Location, "DB used: %d", db);
 
 			loc = libipv6calc_db_wrapper_IP2Location_open_type(db);
 			info = libipv6calc_db_wrapper_IP2Location_database_info(loc);
@@ -333,14 +327,14 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_db_info_used(void) {
  * wrapper extension: IP2Location_lib_version
  */
 const char * libipv6calc_db_wrapper_IP2Location_lib_version(void) {
-	DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Called: %s", wrapper_ip2location_info);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	const char *result_IP2Location_lib_version;
 	if (dl_IP2Location_handle == NULL) {
 		result_IP2Location_lib_version = "LIBARY-NOT-LOADED";
 	} else {
-		result_IP2Location_lib_version = "version-unknown";
+		result_IP2Location_lib_version = "version-not-provided";
 	};
 
 	return(result_IP2Location_lib_version);
@@ -357,9 +351,7 @@ static char *libipv6calc_db_wrapper_IP2Location_dbfilename(int type) {
 	static char tempstring[NI_MAXHOST];
 	int  entry = -1, i;
 
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called: %s type=%d\n", __FILE__, __func__, wrapper_ip2location_info, type);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
 
 	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_IP2Location_db_file_desc); i++) {
 		if (libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number == type) {
@@ -374,9 +366,7 @@ static char *libipv6calc_db_wrapper_IP2Location_dbfilename(int type) {
 
 	snprintf(tempstring, sizeof(tempstring), "%s/%s", ip2location_db_dir, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].filename);
 
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Finished: %s type=%d has filename=%s\n", __FILE__, __func__, wrapper_ip2location_info, type, tempstring);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Finished: %s type=%d has filename=%s", wrapper_ip2location_info, type, tempstring);
 
 	return(tempstring);
 };
@@ -388,9 +378,7 @@ static char *libipv6calc_db_wrapper_IP2Location_dbfilename(int type) {
 const char *libipv6calc_db_wrapper_IP2Location_dbdescription(int type) {
 	int  entry = -1, i;
 
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called: %s type=%d\n", __FILE__, __func__, wrapper_ip2location_info, type);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
 
 	for (i = 0; i < sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc) / sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc[0]); i++) {
 		if (libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number == type) {
@@ -403,9 +391,7 @@ const char *libipv6calc_db_wrapper_IP2Location_dbdescription(int type) {
 		return("unknown");
 	};
 
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Finished: %s type=%d has description=%s\n", __FILE__, __func__, wrapper_ip2location_info, type, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Finished: %s type=%d has description=%s", wrapper_ip2location_info, type, libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
 
 	return(libipv6calc_db_wrapper_IP2Location_db_file_desc[i].description);
 };
@@ -419,7 +405,7 @@ int libipv6calc_db_wrapper_IP2Location_db_avail(int type) {
 	char *filename;
 	int r = 0;
 
-	DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
 
 	filename = libipv6calc_db_wrapper_IP2Location_dbfilename(type);
 
@@ -430,9 +416,9 @@ int libipv6calc_db_wrapper_IP2Location_db_avail(int type) {
 	r = (access(filename, R_OK) == 0) ? 1:0;
 
 	if (r == 0) {
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Finished: %s type=%d (still unknown) (r=%d: %s)", wrapper_ip2location_info, type, r, strerror(errno));
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Finished: %s type=%d (still unknown) (r=%d: %s)", wrapper_ip2location_info, type, r, strerror(errno));
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Finished: %s type=%d (%s) (r=%d)", wrapper_ip2location_info, type, filename, r);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Finished: %s type=%d (%s) (r=%d)", wrapper_ip2location_info, type, filename, r);
 	};
 
 END_libipv6calc_db_wrapper:
@@ -447,7 +433,7 @@ IP2Location *libipv6calc_db_wrapper_IP2Location_open_type(int type) {
 	char *filename;
 	int  entry = -1, i;
 
-	DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s type=%d", wrapper_ip2location_info, type);
 
 	for (i = 0; i < sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc) / sizeof(libipv6calc_db_wrapper_IP2Location_db_file_desc[0]); i++) {
 		if (libipv6calc_db_wrapper_IP2Location_db_file_desc[i].number == type) {
@@ -480,7 +466,7 @@ IP2Location *libipv6calc_db_wrapper_IP2Location_open_type(int type) {
  * wrapper: IP2Location_open
  */
 IP2Location *libipv6calc_db_wrapper_IP2Location_open(char *db) {
-	DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Called: %s filename=%s", wrapper_ip2location_info, db);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s filename=%s", wrapper_ip2location_info, db);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	IP2Location *loc = NULL;
@@ -493,7 +479,7 @@ IP2Location *libipv6calc_db_wrapper_IP2Location_open(char *db) {
 	};
 
 	if (dl_status_IP2Location_open == IPV6CALC_DL_STATUS_UNKNOWN) {
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Call dlsym: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -506,14 +492,13 @@ IP2Location *libipv6calc_db_wrapper_IP2Location_open(char *db) {
 		};
 
 		dl_status_IP2Location_open = IPV6CALC_DL_STATUS_OK;
-
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Called dlsym successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_open == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
 	loc = (*dl_IP2Location_open.func)(db);
@@ -535,9 +520,7 @@ END_libipv6calc_db_wrapper:
  * wrapper: IP2Location_close
  */
 uint32_t libipv6calc_db_wrapper_IP2Location_close(IP2Location *loc) {
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called: %s\n", __FILE__, __func__, wrapper_ip2location_info);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	uint32_t result = 0;
@@ -550,9 +533,7 @@ uint32_t libipv6calc_db_wrapper_IP2Location_close(IP2Location *loc) {
 	};
 
 	if (dl_status_IP2Location_close == IPV6CALC_DL_STATUS_UNKNOWN) {
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Call dlsym: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -565,20 +546,13 @@ uint32_t libipv6calc_db_wrapper_IP2Location_close(IP2Location *loc) {
 		};
 
 		dl_status_IP2Location_close = IPV6CALC_DL_STATUS_OK;
-
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Called dlsym successful: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_close == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Previous call of dlsym already failed: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Previous call of dlsym already successful: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
 	result = (*dl_IP2Location_close.func)(loc);
@@ -602,9 +576,7 @@ END_libipv6calc_db_wrapper:
 char *libipv6calc_db_wrapper_IP2Location_database_info(IP2Location *loc) {
 	static char resultstring[NI_MAXHOST];
 
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called: %s\n", __FILE__, __func__, wrapper_ip2location_info);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
 
 	if (loc == NULL) {
 		snprintf(resultstring, sizeof(resultstring), "%s", "can't retrieve database information");
@@ -626,9 +598,7 @@ char *libipv6calc_db_wrapper_IP2Location_database_info(IP2Location *loc) {
  * wrapper: IP2Location_free_record
  */ 
 void libipv6calc_db_wrapper_IP2Location_free_record(IP2LocationRecord *record) {
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called: %s\n", __FILE__, __func__, wrapper_ip2location_info);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	const char *dl_symbol = "IP2Location_free_record";
@@ -640,9 +610,7 @@ void libipv6calc_db_wrapper_IP2Location_free_record(IP2LocationRecord *record) {
 	};
 
 	if (dl_status_IP2Location_free_record == IPV6CALC_DL_STATUS_UNKNOWN) {
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Call dlsym: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -655,20 +623,13 @@ void libipv6calc_db_wrapper_IP2Location_free_record(IP2LocationRecord *record) {
 		};
 
 		dl_status_IP2Location_free_record = IPV6CALC_DL_STATUS_OK;
-
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Called dlsym successful: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_free_record == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Previous call of dlsym already failed: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Previous call of dlsym already successful: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
 	(*dl_IP2Location_free_record.func)(record);
@@ -690,9 +651,7 @@ END_libipv6calc_db_wrapper:
  * wrapper: IP2Location_get_country_short
  */
 IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_short(IP2Location *loc, char *ip) {
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called: %s\n", __FILE__, __func__, wrapper_ip2location_info);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s ip=%s", wrapper_ip2location_info, ip);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	IP2LocationRecord *result_IP2Location_get_country_short = NULL;
@@ -705,9 +664,7 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_short(IP2Locat
 	};
 
 	if (dl_status_IP2Location_get_country_long == IPV6CALC_DL_STATUS_UNKNOWN) {
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Call dlsym: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -720,20 +677,13 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_short(IP2Locat
 		};
 
 		dl_status_IP2Location_get_country_short = IPV6CALC_DL_STATUS_OK;
-
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Called dlsym successful: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_get_country_long == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Previous call of dlsym already failed: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Previous call of dlsym already successful: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
 	result_IP2Location_get_country_short = (*dl_IP2Location_get_country_short.func)(loc, ip);
@@ -755,9 +705,7 @@ END_libipv6calc_db_wrapper:
  * wrapper: IP2Location_get_country_long
  */
 IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_long(IP2Location *loc, char *ip) {
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called: %s\n", __FILE__, __func__, wrapper_ip2location_info);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s ip=%s", wrapper_ip2location_info, ip);
 
 #ifdef SUPPORT_IP2LOCATION_DYN
 	IP2LocationRecord *result_IP2Location_get_country_long = NULL;
@@ -770,9 +718,7 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_long(IP2Locati
 	};
 
 	if (dl_status_IP2Location_get_country_long == IPV6CALC_DL_STATUS_UNKNOWN) {
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Call dlsym: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -786,19 +732,13 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_country_long(IP2Locati
 
 		dl_status_IP2Location_get_country_long = IPV6CALC_DL_STATUS_OK;
 
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Called dlsym successful: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_get_country_long == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Previous call of dlsym already failed: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-			fprintf(stderr, "%s/%s: Previous call of dlsym already successful: %s\n", __FILE__, __func__, dl_symbol);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
 	result_IP2Location_get_country_long = (*dl_IP2Location_get_country_long.func)(loc, ip);
@@ -820,10 +760,10 @@ END_libipv6calc_db_wrapper:
  * wrapper: IP2Location_get_all
  */
 IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_all(IP2Location *loc, char *ip) {
-	DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Called: %s", wrapper_ip2location_info);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called: %s", wrapper_ip2location_info);
 
 	if (loc == NULL) {
-		DEBUGPRINT_NA(DEBUG_libipv6addr_db_wrapper, "loc==NULL, return NULL");
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "loc==NULL, return NULL");
 		return(NULL);
 	};
 
@@ -838,7 +778,7 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_all(IP2Location *loc,
 	};
 
 	if (dl_status_IP2Location_get_all == IPV6CALC_DL_STATUS_UNKNOWN) {
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Call dlsym: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Call dlsym: %s", dl_symbol);
 
 		dlerror();    /* Clear any existing error */
 
@@ -852,13 +792,13 @@ IP2LocationRecord *libipv6calc_db_wrapper_IP2Location_get_all(IP2Location *loc,
 
 		dl_status_IP2Location_get_all = IPV6CALC_DL_STATUS_OK;
 
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Called dlsym successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called dlsym successful: %s", dl_symbol);
 	} else if (dl_status_IP2Location_get_all == IPV6CALC_DL_STATUS_ERROR) {
 		/* already known issue */
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already failed: %s", dl_symbol);
 		goto END_libipv6calc_db_wrapper;
 	} else {
-		DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Previous call of dlsym already successful: %s", dl_symbol);
 	};
 
 	result_IP2Location_get_all = (*dl_IP2Location_get_all.func)(loc, ip);
@@ -887,9 +827,8 @@ END_libipv6calc_db_wrapper:
  */
 int libipv6calc_db_wrapper_IP2Location_has_features(uint32_t features) {
 	int result = -1;
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called with feature value to test: 0x%08x\n", __FILE__, __func__, features);
-	};
+
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called with feature value to test: 0x%08x", features);
 
 	if ((wrapper_features_IP2Location & features) == features) {
 		result = 1;
@@ -897,9 +836,7 @@ int libipv6calc_db_wrapper_IP2Location_has_features(uint32_t features) {
 		result = 0;
 	};
 
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Return with result: %d\n", __FILE__, __func__, result);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Return with result: %d", result);
 	return(result);
 };
 
@@ -909,44 +846,51 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_country_code_by_addr(char *addr
 	IP2LocationRecord *record;
 
 	int IP2Location_type = 0;
-	char *IP2Location_result_ptr;
+	char *IP2Location_result_ptr = NULL;
 
-	DEBUGPRINT_WA(DEBUG_libipv6addr_db_wrapper, "Called with addr=%s proto=%d", addr, proto);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called with addr=%s proto=%d", addr, proto);
 
 	if (proto == 4) {
 		IP2Location_type = IP2LOCATION_DB_IP_COUNTRY;
 	} else if (proto == 6) {
 		IP2Location_type = IP2LOCATION_DB_IPV6_COUNTRY;
 	} else {
-		return (NULL);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Unsupported proto: %d", proto);
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	loc = libipv6calc_db_wrapper_IP2Location_open_type(IP2Location_type);
 
 	if (loc == NULL) {
-		return (NULL);
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "Error opening IP2Location by type");
+		goto END_libipv6calc_db_wrapper;
 	};
 
 	record = libipv6calc_db_wrapper_IP2Location_get_country_short(loc, addr);
 
 	if (record == NULL) {
-		return (NULL);
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "libipv6calc_db_wrapper_IP2Location_get_country_short did not return a record");
+		goto END_libipv6calc_db_wrapper_close;
 	};
 
 	IP2Location_result_ptr = record->country_short;
 
 	if (IP2Location_result_ptr == NULL) {
-		return (NULL);
+		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper, "libipv6calc_db_wrapper_IP2Location_get_country_short did not contain a country_short code");
+		goto END_libipv6calc_db_wrapper_close;
 	};
 
 	if (strlen(IP2Location_result_ptr) > 2) {
-		return (NULL);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "libipv6calc_db_wrapper_IP2Location_get_country_short did not return a proper country_short code (length > 2): %s", IP2Location_result_ptr);
+		goto END_libipv6calc_db_wrapper_close;
 	};
 
 	IP2LOCATION_DB_USAGE_MAP_TAG(IP2Location_type);
 
+END_libipv6calc_db_wrapper_close:
 	libipv6calc_db_wrapper_IP2Location_close(loc);
 
+END_libipv6calc_db_wrapper:
 	return(IP2Location_result_ptr);
 };
 
@@ -958,9 +902,7 @@ char *libipv6calc_db_wrapper_IP2Location_wrapper_country_name_by_addr(char *addr
 	int IP2Location_type = 0;
 	char *IP2Location_result_ptr;
 
-	if ( (ipv6calc_debug & DEBUG_libipv6addr_db_wrapper) != 0 ) {
-		fprintf(stderr, "%s/%s: Called with addr=%s proto=%d\n", __FILE__, __func__, addr, proto);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper, "Called with addr=%s proto=%d", addr, proto);
 
 	if (proto == 4) {
 		IP2Location_type = IP2LOCATION_DB_IP_COUNTRY;
