@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc/ipv6calc.c
- * Version    : $Id: ipv6calc.c,v 1.102 2013/11/15 07:18:39 ds6peter Exp $
- * Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calc.c,v 1.111 2014/05/11 09:49:38 ds6peter Exp $
+ * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Central program (main)
@@ -42,13 +42,8 @@
 #include "libeui64.h"
 #include "config.h"
 #include "libieee.h"
-#include "../databases/ieee-oui/dbieee_oui.h"
-#include "../databases/ieee-oui36/dbieee_oui36.h"
-#include "../databases/ieee-iab/dbieee_iab.h"
 #include "libipv4addr.h"
-#include "../databases/ipv4-assignment/dbipv4addr_assignment.h"
 #include "libipv6addr.h"
-#include "../databases/ipv6-assignment/dbipv6addr_assignment.h"
 
 #include "../databases/lib/libipv6calc_db_wrapper.h"
 
@@ -69,7 +64,7 @@
 #endif
 
 
-long int ipv6calc_debug = 0;
+long int ipv6calc_debug = 0; // ipv6calc_debug usage ok
 
 /* pipe support */
 int input_is_pipe = 0;
@@ -86,7 +81,6 @@ int feature_kp      = 0; // will be checked later
 
 /**************************************************/
 /* main */
-#define DEBUG_function_name "ipv6calc/main"
 int main(int argc, char *argv[]) {
 	char resultstring[NI_MAXHOST] = "";
 	char resultstring2[NI_MAXHOST] = "";
@@ -112,6 +106,10 @@ int main(int argc, char *argv[]) {
 	ipv6calc_macaddr  macaddr;
 	ipv6calc_eui64addr  eui64addr;
 
+	/* used simple data */
+	uint32_t asn;
+	int asn_valid = 0;
+
 	/* filter structure */
 	s_ipv6calc_filter_master filter_master;
 	libipv6calc_filter_clear(&filter_master);
@@ -142,7 +140,7 @@ int main(int argc, char *argv[]) {
 	int    longopts_maxentries = 0;
 
 	/* initialize debug value from environment for bootstrap debugging */
-	ipv6calc_debug_from_env();
+	ipv6calc_debug_from_env(); // ipv6calc_debug usage ok
 
 	/* add options */
 	ipv6calc_options_add_common_anon(shortopts, sizeof(shortopts), longopts, &longopts_maxentries);
@@ -162,20 +160,17 @@ int main(int argc, char *argv[]) {
 	};
 
 	/* Fetch the command-line arguments. */
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s/%s: Start parsing options: shortopts=%s\n", __FILE__, __func__, shortopts);
-
+	DEBUGSECTION_BEGIN(DEBUG_ipv6calc_general) 
+		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Start parsing options: shortopts=%s", shortopts); 
 		i = 0;
 		while(longopts[i].name != NULL) {
-			fprintf(stderr, "%s/%s: Long option: %s/%d/%08x\n", __FILE__, __func__, longopts[i].name, longopts[i].has_arg, longopts[i].val);
+			DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Long option: %s/%d/%08x", longopts[i].name, longopts[i].has_arg, longopts[i].val);
 			i++;
 		};
-	};
+	DEBUGSECTION_END
 	
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "%s/%s: Parsing option: 0x%08x\n", __FILE__, __func__, i);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Parsing option: 0x%08x", i);
 
 		/* catch "common basic" options */
 		result = ipv6calcoptions_common_basic(i, optarg, longopts);
@@ -215,9 +210,7 @@ int main(int argc, char *argv[]) {
 			case 'h':
 			case '?':
 				command |= CMD_printhelp;
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: help option detected\n", DEBUG_function_name);
-				};
+				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "help option detected");
 				break;
 				
 			case 'L':
@@ -248,11 +241,6 @@ int main(int argc, char *argv[]) {
 				command = CMD_printexamples;
 				break;
 
-			case CMD_printoldoptions:
-				command = CMD_printoldoptions;
-				break;
-
-
 			/* backward compatibility/shortcut commands */
 			case 'r':
 			case CMD_addr_to_ip6int:
@@ -353,11 +341,11 @@ int main(int argc, char *argv[]) {
 				break;
 
 			case CMD_6rd_relay_prefix:
-				retval = addr_to_ipv4addrstruct(optarg, resultstring, &ipv4addr2);
+				retval = addr_to_ipv4addrstruct(optarg, resultstring, sizeof(resultstring), &ipv4addr2);
 				break;
 
 			case CMD_6rd_prefix:
-				retval = addr_to_ipv6addrstruct(optarg, resultstring, &ipv6addr);
+				retval = addr_to_ipv6addrstruct(optarg, resultstring, sizeof(resultstring), &ipv6addr);
 				break;
 
 			/* format options */
@@ -403,7 +391,7 @@ int main(int argc, char *argv[]) {
 				break;
 				
 			case FORMATOPTION_NUM_forceprefix + FORMATOPTION_NUM_HEAD:
-				if (ipv6calc_debug != 0) fprintf(stderr, "%s: format option 'forceprefix' selected\n", DEBUG_function_name);
+				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "format option 'forceprefix' selected");
 				if ((atoi(optarg) >= 1) && (atoi(optarg) <= 128)) {
 					force_prefix = atoi(optarg);
 					formatoptions |= FORMATOPTION_forceprefix;
@@ -414,7 +402,7 @@ int main(int argc, char *argv[]) {
 				break;
 				
 			case FORMATOPTION_NUM_printstart + FORMATOPTION_NUM_HEAD:
-				if (ipv6calc_debug != 0) fprintf(stderr, "%s: format option 'printstart' selected\n", DEBUG_function_name);
+				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "format option 'printstart' selected");
 				if ((atoi(optarg) >= 1) && (atoi(optarg) <= 128)) {
 					bit_start = atoi(optarg);
 					formatoptions |= FORMATOPTION_printstart;
@@ -425,7 +413,7 @@ int main(int argc, char *argv[]) {
 				break;
 				
 			case FORMATOPTION_NUM_printend + FORMATOPTION_NUM_HEAD:
-				if (ipv6calc_debug != 0) fprintf(stderr, "%s: format option 'printend' selected\n", DEBUG_function_name);
+				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "format option 'printend' selected");
 				if ((atoi(optarg) >= 1) && (atoi(optarg) <= 128)) {
 					bit_end = atoi(optarg);
 					formatoptions |= FORMATOPTION_printend;
@@ -456,9 +444,7 @@ int main(int argc, char *argv[]) {
 			/* new options */
 			case 'I':	
 			case CMD_inputtype:
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: Got input string: %s\n", DEBUG_function_name, optarg);
-				};
+				DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Got input string: %s", optarg);
 				if ((strcmp(optarg, "-?") == 0) || (strcmp(optarg, "-h") == 0) || (strcmp(optarg, "--help") == 0) ) {
 					inputtype = FORMAT_auto;
 					command = CMD_printhelp;
@@ -476,9 +462,7 @@ int main(int argc, char *argv[]) {
 				
 			case 'O':	
 			case CMD_outputtype:
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: Got output string: %s\n", DEBUG_function_name, optarg);
-				};
+				DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Got output string: %s", optarg);
 				if ((strcmp(optarg, "-?") == 0) || (strcmp(optarg, "-h") == 0) || (strcmp(optarg, "--help") == 0) ) {
 					outputtype = FORMAT_auto;
 					command = CMD_printhelp;
@@ -534,7 +518,7 @@ int main(int argc, char *argv[]) {
 				
 			default:
 				fprintf(stderr, "Usage: (see '%s --command -?|-h|--help' for more help)\n", PROGRAM_NAME);
-				ipv6calc_printhelp();
+				ipv6calc_printhelp(longopts, ipv6calc_longopts_shortopts_map);
 				exit(EXIT_FAILURE);
 		};
 	};
@@ -560,7 +544,7 @@ int main(int argc, char *argv[]) {
 	/* print help handling */
 	if (command == CMD_printhelp) {
 		if ( (outputtype == FORMAT_undefined) && (inputtype == FORMAT_undefined) && (action == ACTION_undefined)) {
-			ipv6calc_printhelp();
+			ipv6calc_printhelp(longopts, ipv6calc_longopts_shortopts_map);
 			exit(EXIT_FAILURE);
 		} else if (outputtype == FORMAT_auto) {
 			if (inputtype == FORMAT_undefined) {
@@ -569,7 +553,11 @@ int main(int argc, char *argv[]) {
 			printhelp_outputtypes(inputtype, formatoptions);
 			exit(EXIT_FAILURE);
 		} else if (inputtype == FORMAT_auto) {
-			printhelp_inputtypes(formatoptions);
+			if (outputtype == FORMAT_undefined) {
+				printhelp_inputtypes(formatoptions);
+			} else {
+				printhelp_output_dispatcher(outputtype);
+			};
 			exit(EXIT_FAILURE);
 		} else if (action == ACTION_auto) {
 			printhelp_actiontypes(formatoptions, ipv6calc_longopts);
@@ -587,7 +575,7 @@ int main(int argc, char *argv[]) {
 		exit(EXIT_FAILURE);
 	};
 
-	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Debug value:%08lx command:%08lx inputtype:%08lx outputtype:%08lx action:%08lx formatoptions:%08lx", (unsigned long) ipv6calc_debug, (unsigned long) command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action, (unsigned long) formatoptions);
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Debug value:%08lx command:%08lx inputtype:%08lx outputtype:%08lx action:%08lx formatoptions:%08lx", (unsigned long) ipv6calc_debug, (unsigned long) command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action, (unsigned long) formatoptions); // ipv6calc_debug usage ok
 
 	/* do work depending on selection */
 	if ((command & CMD_printversion) != 0) {
@@ -607,11 +595,6 @@ int main(int argc, char *argv[]) {
 		};
 	};
 
-	if (command == CMD_printoldoptions) {
-		printhelp_oldoptions(longopts);
-		exit(EXIT_FAILURE);
-	};
-	
 	if (argc > 0) {
 		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Got input %s", argv[0]);
 	} else {
@@ -657,7 +640,7 @@ PIPE_input:
 		linecounter++;
 
 		if (linecounter == 1) {
-			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Ok, proceeding stdin...\n");
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Ok, proceeding stdin...");
 		};
 		
 		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Line: %d", linecounter);
@@ -697,7 +680,7 @@ PIPE_input:
 			goto PIPE_input;
 		};
 
-		snprintf(token, sizeof(token) - 1, "%s", charptr);
+		snprintf(token, sizeof(token), "%s", charptr);
 		
 		input1 = token;
 		inputc = 1;
@@ -739,7 +722,7 @@ PIPE_input:
 		inputtype = libipv6calc_autodetectinput(input1);
 
 		if ( inputtype != FORMAT_undefined ) {
-			for (i = 0; i < (int) (sizeof(ipv6calc_formatstrings) / sizeof(ipv6calc_formatstrings[0])); i++) {
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
 				if (inputtype == ipv6calc_formatstrings[i].number) {
 					if ((formatoptions & FORMATOPTION_quiet) == 0) {
 						fprintf(stderr, "found type: %s\n", ipv6calc_formatstrings[i].token);
@@ -780,7 +763,7 @@ PIPE_input:
 			if ((formatoptions & FORMATOPTION_quiet) == 0) {
 				fprintf(stderr, "No action type specified, try autodetection...");
 			};
-			for (i = 0; i < (int) (sizeof(ipv6calc_actionstrings) / sizeof(ipv6calc_actionstrings[0])); i++) {
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_actionstrings); i++) {
 				if (action == ipv6calc_actionstrings[i].number) {
 					if ((formatoptions & FORMATOPTION_quiet) == 0) {
 						fprintf(stderr, "found type: %s\n", ipv6calc_actionstrings[i].token);
@@ -794,7 +777,7 @@ PIPE_input:
 	/* check formatoptions for validity */
 	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "check format option of output type: 0x%08lx", (unsigned long) outputtype);
 		
-	for (i = 0; i < (int) (sizeof(ipv6calc_outputformatoptionmap) / sizeof(ipv6calc_outputformatoptionmap[0])); i++) {
+	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_outputformatoptionmap); i++) {
 		if (outputtype != ipv6calc_outputformatoptionmap[i][0]) {
 			continue;
 		};
@@ -811,7 +794,7 @@ PIPE_input:
 		fprintf(stderr, " Unsupported format option(s):\n");
 
 		/* run through format options */
-		for (j = 0; j < (int) (sizeof(ipv6calc_formatoptionstrings) / sizeof (ipv6calc_formatoptionstrings[0])); j++) {
+		for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatoptionstrings); j++) {
 			if ( (ipv6calc_formatoptionstrings[j].number & FORMATOPTION_quiet) != 0 ) {
 				/* skip format option "quiet" on check */
 				continue;
@@ -864,6 +847,13 @@ PIPE_input:
 			if (inputc < 2) { printhelp_missinginputdata(); exit(EXIT_FAILURE); };
 			break;
 
+		case FORMAT_asn:
+			if (command != CMD_showinfo) {
+				fprintf(stderr, " Input-type only supported for 'showinfo'\n");
+				exit(EXIT_FAILURE);
+			};
+			break;
+
 		case FORMAT_auto_noresult:
 		default:
 			fprintf(stderr, " Input-type isn't autodetected\n");
@@ -872,79 +862,92 @@ PIPE_input:
 
 	switch (inputtype) {
 		case FORMAT_ipv6addr:
-			retval = addr_to_ipv6addrstruct(input1, resultstring, &ipv6addr);
+			retval = addr_to_ipv6addrstruct(input1, resultstring, sizeof(resultstring), &ipv6addr);
 			argc--;
 			break;
 
 		case FORMAT_ipv6literal:
-			retval = addrliteral_to_ipv6addrstruct(input1, resultstring, &ipv6addr);
+			retval = addrliteral_to_ipv6addrstruct(input1, resultstring, sizeof(resultstring), &ipv6addr);
 			argc--;
 			break;
 
 		case FORMAT_ipv4addr:
-			retval = addr_to_ipv4addrstruct(input1, resultstring, &ipv4addr);
+			retval = addr_to_ipv4addrstruct(input1, resultstring, sizeof(resultstring), &ipv4addr);
 			argc--;
 			break;
 			
 		case FORMAT_ipv4hex:
-			retval = addrhex_to_ipv4addrstruct(input1, resultstring, &ipv4addr, 0);
+			retval = addrhex_to_ipv4addrstruct(input1, resultstring, sizeof(resultstring), &ipv4addr, 0);
 			argc--;
 			break;
 
 		case FORMAT_ipv4revhex:
-			retval = addrhex_to_ipv4addrstruct(input1, resultstring, &ipv4addr, 1);
+			retval = addrhex_to_ipv4addrstruct(input1, resultstring, sizeof(resultstring), &ipv4addr, 1);
 			argc--;
 			break;
 
 		case FORMAT_base85:
-			retval = base85_to_ipv6addrstruct(input1, resultstring, &ipv6addr);
+			retval = base85_to_ipv6addrstruct(input1, resultstring, sizeof(resultstring), &ipv6addr);
 			argc--;
 			break;
 			
 		case FORMAT_mac:
-			retval = mac_to_macaddrstruct(input1, resultstring, &macaddr);
+			retval = mac_to_macaddrstruct(input1, resultstring, sizeof(resultstring), &macaddr);
 			argc--;
 			break;
 
 		case FORMAT_eui64:
-			retval = libeui64_addr_to_eui64addrstruct(input1, resultstring, &eui64addr);
+			retval = libeui64_addr_to_eui64addrstruct(input1, resultstring, sizeof(resultstring), &eui64addr);
 			argc--;
 			break;
 
 		case FORMAT_ifinet6:
 			if (inputc < 2) {
-				retval = libifinet6_ifinet6_to_ipv6addrstruct(input1, resultstring, &ipv6addr);
+				retval = libifinet6_ifinet6_to_ipv6addrstruct(input1, resultstring, sizeof(resultstring), &ipv6addr);
 			} else {
-				retval = libifinet6_ifinet6_withprefixlength_to_ipv6addrstruct(input1, input2, resultstring, &ipv6addr);
+				retval = libifinet6_ifinet6_withprefixlength_to_ipv6addrstruct(input1, input2, resultstring, sizeof(resultstring), &ipv6addr);
 			};
 			break;
 
 		case FORMAT_iid_token:
 			/* Get first interface identifier */
-			retval = identifier_to_ipv6addrstruct(input1, resultstring, &ipv6addr);
+			retval = identifier_to_ipv6addrstruct(input1, resultstring, sizeof(resultstring), &ipv6addr);
 			if (retval != 0) { break; };
 			
 			/* Get second token */
-			retval = tokenlsb64_to_ipv6addrstruct(input2, resultstring, &ipv6addr2);
+			retval = tokenlsb64_to_ipv6addrstruct(input2, resultstring, sizeof(resultstring), &ipv6addr2);
 			break;
 			
 		case FORMAT_prefix_mac:
 			/* Get first: IPv6 prefix */
-			retval = addr_to_ipv6addrstruct(input1, resultstring, &ipv6addr);
+			retval = addr_to_ipv6addrstruct(input1, resultstring, sizeof(resultstring), &ipv6addr);
 			if (retval != 0) { break; };
 			
 			/* Get second: MAC address */
-			retval = mac_to_macaddrstruct(input2, resultstring, &macaddr);
+			retval = mac_to_macaddrstruct(input2, resultstring, sizeof(resultstring), &macaddr);
 			break;
 
 		case FORMAT_revnibbles_int:
 		case FORMAT_revnibbles_arpa:
-			retval = librfc1886_nibblestring_to_ipv6addrstruct(input1, &ipv6addr, resultstring);
+			retval = librfc1886_nibblestring_to_ipv6addrstruct(input1, &ipv6addr, resultstring, sizeof(resultstring));
 			argc--;
 			break;
 			
 		case FORMAT_bitstring:
-			retval = librfc2874_bitstring_to_ipv6addrstruct(input1, &ipv6addr, resultstring);
+			retval = librfc2874_bitstring_to_ipv6addrstruct(input1, &ipv6addr, resultstring, sizeof(resultstring));
+			argc--;
+			break;
+
+		case FORMAT_asn:
+			retval = sscanf(input1, "%d", &asn);
+			if (retval == 0) {
+				retval = -1;
+				snprintf(resultstring, sizeof(resultstring), "error parsing ASN");
+			} else {
+				DEBUGPRINT_WA(DEBUG_ipv6calc_general, "ASN parsed: %d", asn);
+				asn_valid = 1;
+				retval = 0;
+			};
 			argc--;
 			break;
 			
@@ -1105,7 +1108,7 @@ PIPE_input:
 		};
 
 		if ( outputtype != FORMAT_undefined ) {
-			for (i = 0; i < (int) (sizeof(ipv6calc_formatstrings) / sizeof(ipv6calc_formatstrings[0])); i++) {
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
 				if (outputtype == ipv6calc_formatstrings[i].number) {
 					if ((formatoptions & FORMATOPTION_quiet) == 0) {
 						fprintf(stderr, "found type: %s\n", ipv6calc_formatstrings[i].token);
@@ -1128,7 +1131,7 @@ PIPE_input:
 	};
 
 	/* clear resultstring */
-	snprintf(resultstring, sizeof(resultstring) - 1, "%s", "");
+	snprintf(resultstring, sizeof(resultstring), "%s", "");
 
 	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Process action (action: 0x%08lx)", (unsigned long) action);
 	
@@ -1155,7 +1158,7 @@ PIPE_input:
 					fprintf(stderr, "No valid IPv6 address given!\n");
 					exit(EXIT_FAILURE);
 				};
-				retval = librfc3056_ipv6addr_to_ipv4addr(&ipv4addr, &ipv6addr, resultstring);
+				retval = librfc3056_ipv6addr_to_ipv4addr(&ipv4addr, &ipv6addr, resultstring, sizeof(resultstring));
 			} else {
 				fprintf(stderr, "Unsupported 6to4 conversion!\n");
 				exit(EXIT_FAILURE);
@@ -1282,7 +1285,7 @@ PIPE_input:
 				exit(EXIT_FAILURE);
 			}
 
-			retval = librfc5569_calc_6rd_local_prefix(&ipv6addr, &ipv4addr2, &ipv4addr, resultstring);
+			retval = librfc5569_calc_6rd_local_prefix(&ipv6addr, &ipv4addr2, &ipv4addr, resultstring, sizeof(resultstring));
 			break;
 
 		case ACTION_filter:
@@ -1309,7 +1312,7 @@ PIPE_input:
 				/* skip everything */
 				DEBUGPRINT_WA(DEBUG_ipv6calc_general, "filter result SKIP: '%s'", linebuffer);
 			} else {
-				snprintf(resultstring, sizeof(resultstring) - 1, "%s", linebuffer);
+				snprintf(resultstring, sizeof(resultstring), "%s", linebuffer);
 			};
 			goto RESULT_print;
 
@@ -1330,14 +1333,10 @@ PIPE_input:
 		exit(EXIT_FAILURE);
 	};
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: End of action\n", DEBUG_function_name);
-	};
+	DEBUGPRINT_NA(DEBUG_ipv6calc_general, "End of action");
 
 	/***** output type *****/
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Process output (outputtype: 0x%08lx)\n", DEBUG_function_name, (unsigned long) outputtype);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Process output (outputtype: 0x%08lx)", (unsigned long) outputtype);
 	
 	/* catch showinfo */	
 	if (command == CMD_showinfo) {
@@ -1358,6 +1357,8 @@ PIPE_input:
 			retval = showinfo_eui48(&macaddr, formatoptions);
 	       	} else if (eui64addr.flag_valid == 1) {
 			retval = showinfo_eui64(&eui64addr, formatoptions);
+	       	} else if (asn_valid == 1) {
+			retval = showinfo_asn(asn, formatoptions);
 		} else {
 		       	fprintf(stderr, "No valid or supported input address given!\n");
 			retval = 1;
@@ -1375,48 +1376,53 @@ PIPE_input:
 			break;
 
 		case FORMAT_base85:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_base85\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_base85");
 			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
-			retval = ipv6addrstruct_to_base85(&ipv6addr, resultstring);
+			retval = ipv6addrstruct_to_base85(&ipv6addr, resultstring, sizeof(resultstring));
 			break;
 				
 		case FORMAT_bitstring:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_bitstring\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_bitstring");
 			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
-			if (ipv6calc_debug != 0) {
-				fprintf(stderr, "%s: Call 'librfc2874_addr_to_bitstring'\n", DEBUG_function_name);
-			};
-			retval = librfc2874_addr_to_bitstring(&ipv6addr, resultstring, formatoptions);
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Call 'librfc2874_addr_to_bitstring'");
+			retval = librfc2874_addr_to_bitstring(&ipv6addr, resultstring, sizeof(resultstring), formatoptions);
 			break;
 			
 		case FORMAT_octal:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_octal\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_octal");
 			if (ipv4addr.flag_valid == 1) {
-				retval = libipv4addr_to_octal(&ipv4addr, resultstring, formatoptions);
+				retval = libipv4addr_to_octal(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
 			} else if (ipv6addr.flag_valid == 1) {
-				retval = libipv6addr_to_octal(&ipv6addr, resultstring, formatoptions);
+				retval = libipv6addr_to_octal(&ipv6addr, resultstring, sizeof(resultstring), formatoptions);
 			};
 			break;
 				
 		case FORMAT_hex:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_hex\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_hex");
 			if (ipv4addr.flag_valid == 1) {
-				retval = libipv4addr_to_hex(&ipv4addr, resultstring, formatoptions);
+				retval = libipv4addr_to_hex(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
 			} else if (ipv6addr.flag_valid == 1) {
-				retval = libipv6addr_to_hex(&ipv6addr, resultstring, formatoptions);
+				retval = libipv6addr_to_hex(&ipv6addr, resultstring, sizeof(resultstring), formatoptions);
+			};
+			break;
+
+		case FORMAT_ipv4hex:
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ipv4hex");
+			if (ipv4addr.flag_valid == 1) {
+				retval = libipv4addr_to_hex(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
 			};
 			break;
 				
 		case FORMAT_revnibbles_int:
 		case FORMAT_revnibbles_arpa:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_revnibbles_int/arpa\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_revnibbles_int/arpa");
 			if (ipv6addr.flag_valid == 1) {
 				switch (outputtype) {
 					case FORMAT_revnibbles_int:
-						retval = librfc1886_addr_to_nibblestring(&ipv6addr, resultstring, formatoptions, "ip6.int.");
+						retval = librfc1886_addr_to_nibblestring(&ipv6addr, resultstring, sizeof(resultstring), formatoptions, "ip6.int.");
 						break;
 					case FORMAT_revnibbles_arpa:
-						retval = librfc1886_addr_to_nibblestring(&ipv6addr, resultstring, formatoptions, "ip6.arpa.");
+						retval = librfc1886_addr_to_nibblestring(&ipv6addr, resultstring, sizeof(resultstring), formatoptions, "ip6.arpa.");
 						break;
 				};
 			} else {
@@ -1425,27 +1431,27 @@ PIPE_input:
 			break;
 				
 		case FORMAT_revipv4:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_revipv4\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_revipv4");
 			if (ipv4addr.flag_valid == 1) {
-				retval = libipv4addr_to_reversestring(&ipv4addr, resultstring, formatoptions);
+				retval = libipv4addr_to_reversestring(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
 			} else {
 			       fprintf(stderr, "No valid IPv4 address given!\n"); exit(EXIT_FAILURE);
 		       	};
 			break;
 			
 		case FORMAT_ifinet6:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_ifinet6\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ifinet6");
 			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
-			retval = libifinet6_ipv6addrstruct_to_ifinet6(&ipv6addr, resultstring);
+			retval = libifinet6_ipv6addrstruct_to_ifinet6(&ipv6addr, resultstring, sizeof(resultstring));
 			break;
 
 		case FORMAT_ipv6addr:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_ipv6addr\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ipv6addr");
 			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
 			if ((formatoptions & (FORMATOPTION_printuncompressed | FORMATOPTION_printfulluncompressed | FORMATOPTION_printprefix | FORMATOPTION_printsuffix)) != 0) {
-				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, formatoptions);
+				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, sizeof(resultstring), formatoptions);
 			} else {
-				retval = librfc1884_ipv6addrstruct_to_compaddr(&ipv6addr, resultstring, formatoptions);
+				retval = librfc1884_ipv6addrstruct_to_compaddr(&ipv6addr, resultstring, sizeof(resultstring), formatoptions);
 			};
 
 			if ((formatoptions & FORMATOPTION_print_iid_var) == FORMATOPTION_print_iid_var) {
@@ -1464,22 +1470,22 @@ PIPE_input:
 			break;
 
 		case FORMAT_ipv6literal:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_ipv6literal\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ipv6literal");
 			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
 			if ((formatoptions & (FORMATOPTION_printuncompressed | FORMATOPTION_printfulluncompressed)) != 0) {
-				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, formatoptions | FORMATOPTION_literal);
+				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, sizeof(resultstring), formatoptions | FORMATOPTION_literal);
 			} else {
-				retval = librfc1884_ipv6addrstruct_to_compaddr(&ipv6addr, resultstring, formatoptions | FORMATOPTION_literal);
+				retval = librfc1884_ipv6addrstruct_to_compaddr(&ipv6addr, resultstring, sizeof(resultstring), formatoptions | FORMATOPTION_literal);
 			};
 			break;
 			
 			
 		case FORMAT_ipv4addr:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_ipv4addr\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ipv4addr");
 			if (ipv4addr.flag_valid != 1) { fprintf(stderr, "No valid IPv4 address given!\n"); exit(EXIT_FAILURE); };
-			retval = libipv4addr_ipv4addrstruct_to_string(&ipv4addr, resultstring, formatoptions);
+			retval = libipv4addr_ipv4addrstruct_to_string(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
 			break;
-			
+
 		case FORMAT_eui64:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_eui64");
 
@@ -1487,32 +1493,32 @@ PIPE_input:
 				if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid EUI-64 identifier given!\n"); exit(EXIT_FAILURE); };
 				if (ipv6addr.prefixlength != 64) { fprintf(stderr, "No valid EUI-64 identifier given!\n"); exit(EXIT_FAILURE); };
 				formatoptions |= FORMATOPTION_printsuffix;
-				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, formatoptions);
+				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, sizeof(resultstring), formatoptions);
 			} else if (action == ACTION_anonymize) {
-				retval = libeui64_eui64addrstruct_to_string(&eui64addr, resultstring, formatoptions);
+				retval = libeui64_eui64addrstruct_to_string(&eui64addr, resultstring, sizeof(resultstring), formatoptions);
 			} else {
 				fprintf(stderr, "Specify proper action or input for output format: eui64\n"); exit(EXIT_FAILURE);
 			};
 			break;
 			
 		case FORMAT_mac:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_mac\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_mac");
 			if (macaddr.flag_valid != 1) { fprintf(stderr, "No valid MAC address given!\n"); exit(EXIT_FAILURE); };
-			retval = macaddrstruct_to_string(&macaddr, resultstring, formatoptions);
+			retval = macaddrstruct_to_string(&macaddr, resultstring, sizeof(resultstring), formatoptions);
 			break;
 			
 		case FORMAT_iid_token:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_iid_token\n", DEBUG_function_name); }
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_iid_token");
 			if (ipv6addr.flag_valid != 1 || ipv6addr2.flag_valid != 1) { fprintf(stderr, "No valid IPv6 addresses given!\n"); exit(EXIT_FAILURE); };
 			/* get interface identifier */
-			retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring2, formatoptions | FORMATOPTION_printsuffix);
+			retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring2, sizeof(resultstring2), formatoptions | FORMATOPTION_printsuffix);
 			if (retval != 0) { break; };
 			
 			/* get token */
-			retval = libipv6addr_ipv6addrstruct_to_tokenlsb64(&ipv6addr2, resultstring3, formatoptions);
+			retval = libipv6addr_ipv6addrstruct_to_tokenlsb64(&ipv6addr2, resultstring3, sizeof(resultstring3), formatoptions);
 			
 			/* cat together */
-			snprintf(resultstring, sizeof(resultstring) - 1, "%s %s", resultstring2, resultstring3);
+			snprintf(resultstring, sizeof(resultstring), "%s %s", resultstring2, resultstring3);
 			break;
 
 
@@ -1521,9 +1527,7 @@ PIPE_input:
 			exit(EXIT_FAILURE);
 	};
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: End of output handling\n", DEBUG_function_name);
-	};
+	DEBUGPRINT_NA(DEBUG_ipv6calc_general, "End of output handling");
 
 RESULT_print:
 	/* print result */
@@ -1544,4 +1548,3 @@ RESULT_print:
 
 	exit(retval);
 };
-#undef DEBUG_function_name
