@@ -2,8 +2,8 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6calc.sh
-# Version    : $Id: test_ipv6calc.sh,v 1.44 2013/11/02 16:41:01 ds6peter Exp $
-# Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: test_ipv6calc.sh,v 1.47 2014/04/26 13:03:56 ds6peter Exp $
+# Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc conversions
 
@@ -26,6 +26,10 @@ source ./test_scenarios.sh
 testscenarios() {
 # Command								Expected result (no space between "=" and result)
 cat <<END | grep -v '^#'
+## Machine readable format
+-m -F ::1								=IPV6=0000:0000:0000:0000:0000:0000:0000:0001
+-m ::1									=IPV6=::1
+-m 1.2.3.4								=IPV4=1.2.3.4
 ## ip6.int.
 --addr_to_ip6int 3ffe:ffff:100:f101::1					=1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.f.f.f.f.e.f.f.3.ip6.int.
 --in ipv6 --out revnibbles.int 3ffe:ffff:100:f101::1			=1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.f.f.f.f.e.f.f.3.ip6.int.
@@ -37,6 +41,9 @@ cat <<END | grep -v '^#'
 -a --uppercase 3ffe::1/64						=0.0.0.0.0.0.0.0.0.0.0.0.E.F.F.3.IP6.ARPA.
 -a -u 3ffe::1/64							=0.0.0.0.0.0.0.0.0.0.0.0.E.F.F.3.IP6.ARPA.
 --out revnibbles.arpa abcd:1234:5678:abcd:1234:1234:1234:1234/125	=0.3.2.1.4.3.2.1.4.3.2.1.4.3.2.1.d.c.b.a.8.7.6.5.4.3.2.1.d.c.b.a.ip6.arpa.
+-a --printstart 49 --printend 64 2001:a60:1168:0001:489c:1212:34fd:130f/64 	=1.0.0.0
+-a --printprefix 2001:a60:1168:0001:489c:1212:34fd:130f/64 			=1.0.0.0.8.6.1.1.0.6.a.0.1.0.0.2.ip6.arpa.
+-a --printsuffix 2001:a60:1168:0001:489c:1212:34fd:130f/64 			=f.0.3.1.d.f.4.3.2.1.2.1.c.9.8.4
 ## to uncompressed
 --addr_to_compressed 3ffe:ffff:0100:f101:0000:0000:0000:0001		=3ffe:ffff:100:f101::1
 --in ipv6 --out ipv6 --printcompressed 3ffe:ffff:0100:f101:0000:0000:0000:0001 =3ffe:ffff:100:f101::1
@@ -247,7 +254,7 @@ testscenarios | sed 's/NOPIPETEST//' | while read line; do
 
 	# extract result
 	command="`echo $line | awk -F= '{ print $1 }' | sed 's/ $//g'`"
-	result="`echo $line | awk -F= '{ print $2 }'`"
+	result="`echo $line | awk -F= '{ for (i=2; i <= NF; i++) printf "%s%s", $i, (i<NF) ? "=" : ""; }'`"
 	if [ -z "$result" -o -z "$command" ]; then
 		echo "Something is wrong in line '$line'"
 		exit 1
@@ -270,6 +277,27 @@ testscenarios | sed 's/NOPIPETEST//' | while read line; do
 	fi
 done || exit 1 
 
+
+echo "Run 'ipv6calc' action 'genprivacyiid'..."
+testscenarios_genprivacyiid | while read in1 in2 out1 out2; do
+	echo "Test './ipv6calc -q -A genprivacyiid $in1 $in2'"
+	result="`./ipv6calc -A genprivacyiid $in1 $in2`"
+	retval=$?
+
+	if [ $retval -ne 0 ]; then
+		echo "Error executing 'ipv6calc'!"
+		exit 1
+	fi
+
+	if [ "$result" != "$out1 $out2" ]; then
+		echo "Result is not matching!"
+		echo "Result is      : $result"
+		echo "Result expected: $out1 $out2"
+		exit 1
+	fi
+done || exit 1
+
+
 echo "Run 'ipv6calc' input validation tests...(empty input)"
 ./ipv6calc -m --in -? | while read inputformat; do
 	if echo $inputformat | grep -q '+'; then
@@ -381,7 +409,7 @@ echo "Run 'ipv6calc' pipe tests (2)"
 testscenarios | grep -v "^NOPIPETEST" | while read line; do
 	# extract result
 	command="`echo "$line" | awk -F= '{ print $1 }' | sed 's/ $//g'`"
-	result="`echo "$line" | awk -F= '{ print $2 }'`"
+	result="`echo "$line" | awk -F= '{ for (i=2; i <= NF; i++) printf "%s%s", $i, (i<NF) ? "=" : ""; }'`"
 	#echo "command=$command" >&2
 	stdin="`echo "$command" | awk '{ print $NF }'`"
 	options="`echo "$command" | awk '{ for (i=1; i < NF; i++) printf "%s ", $i; }'`"
