@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_showinfo.sh
-# Version    : $Id: test_showinfo.sh,v 1.32 2013/10/28 07:25:31 ds6peter Exp $
+# Version    : $Id: test_showinfo.sh,v 1.35 2014/04/25 05:48:13 ds6peter Exp $
 # Copyright  : 2002-2011 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc showinfo
@@ -62,7 +62,7 @@ getexamples | while read address separator comment; do
 done || exit 1
 
 # Test reserved IPv4 addresses
-testscenarios_ipv4_reserved | while read address rfc; do
+testscenarios_ipv4_reserved | while read address rfc rest; do
 	echo "$rfc: $address"
 	case $rfc in
 	    RFC*)
@@ -84,7 +84,7 @@ testscenarios_ipv4_reserved | while read address rfc; do
 done || exit 1
 
 # Test reserved IPv6 addresses
-testscenarios_ipv6_reserved | while read address rfc; do
+testscenarios_ipv6_reserved | while read address rfc rest; do
 	echo "$rfc: $address"
 	if ! ./ipv6calc -q -i -m $address | grep ^IPV6_REGISTRY | grep "$rfc"; then
 		echo "ERROR: unexpected result (should: $rfc)"
@@ -134,8 +134,8 @@ testscenarios_showinfo | while read address output; do
 
 	echo "Test: $address for $output"
 	output_escaped="${output//./\\.}"
-	output_escaped="${output_escaped//[/\[}"
-	output_escaped="${output_escaped//]/\]}"
+	output_escaped="${output_escaped//[/\\[}"
+	output_escaped="${output_escaped//]/\\]}"
 	if ! ./ipv6calc -q -i -m $address | grep "^$output_escaped$"; then
 		echo "ERROR: unexpected result ($output_escaped)"
 		./ipv6calc -q -i -m $address
@@ -153,7 +153,7 @@ if ./ipv6calc -v 2>&1 | grep -qw GeoIP; then
 	echo "Run GeoIP tests"
 	getexamples_GeoIP | while read address; do
 		echo "Run GeoIP showinfo on: $address"
-		if ./ipv6calc -q -i -m -G $address | grep ^GEOIP; then
+		if ./ipv6calc -q -i -m $address | grep ^GEOIP; then
 			true
 		else
 			if echo "$address" | grep -q ":"; then
@@ -161,13 +161,13 @@ if ./ipv6calc -v 2>&1 | grep -qw GeoIP; then
 					echo "Expected result (missing GEOIP) because of missing IPv6 support in GeoIP)"
 					true
 				else
-					echo "Unexpected result (missing GEOIP): ./ipv6calc -q -i -m -G $address"
-					./ipv6calc -q -i -m -G $address
+					echo "Unexpected result (missing GEOIP): ./ipv6calc -q -i -m $address"
+					./ipv6calc -q -i -m $address
 					exit 1
 				fi
 			else
-				echo "Unexpected result (missing GEOIP): ./ipv6calc -q -i -m -G $address"
-				./ipv6calc -q -i -m -G $address
+				echo "Unexpected result (missing GEOIP): ./ipv6calc -q -i -m $address"
+				./ipv6calc -q -i -m $address
 				exit 1
 			fi
 		fi
@@ -191,8 +191,8 @@ if ./ipv6calc -v 2>&1 | grep -qw GeoIP; then
 		fi
 		echo "Test: $address for $output"
 		output_escaped="${output//./\\.}"
-		output_escaped="${output_escaped//[/\[}"
-		output_escaped="${output_escaped//]/\]}"
+		output_escaped="${output_escaped//[/\\[}"
+		output_escaped="${output_escaped//]/\\]}"
 		if ! ./ipv6calc -q -i -m $address | grep "^$output_escaped$"; then
 			echo "ERROR: unexpected result ($output_escaped)"
 			./ipv6calc -q -i -m $address
@@ -209,11 +209,11 @@ if ./ipv6calc -v 2>&1 | grep -qw IP2Location; then
 	echo "Run IP2Location tests"
 	getexamples_IP2Location | while read address; do
 		echo "Run IP2Location showinfo on: $address"
-		if ./ipv6calc -q -i -m -L $address | egrep -v '=This (record|parameter) ' | grep ^IP2LOCATION; then
+		if ./ipv6calc -q -i -m $address | egrep -v '=This (record|parameter) ' | grep ^IP2LOCATION; then
 			true
 		else
-			echo "Unexpected result (missing IP2LOCATION): ./ipv6calc -q -i -m -L $address"
-			./ipv6calc -q -i -m -L $address
+			echo "Unexpected result (missing IP2LOCATION): ./ipv6calc -q -i -m $address"
+			./ipv6calc -q -i -m $address
 			exit 1
 		fi
 	done || exit 1
@@ -227,8 +227,8 @@ if ./ipv6calc -v 2>&1 | grep -qw IP2Location; then
 		fi
 		echo "Test: $address for $output"
 		output_escaped="${output//./\\.}"
-		output_escaped="${output_escaped//[/\[}"
-		output_escaped="${output_escaped//]/\]}"
+		output_escaped="${output_escaped//[/\\[}"
+		output_escaped="${output_escaped//]/\\]}"
 		if ! ./ipv6calc -q -i -m $address | grep "^$output_escaped$"; then
 			echo "ERROR: unexpected result ($output_escaped)"
 			./ipv6calc -q -i -m $address
