@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconv.c
- * Version    : $Id: ipv6logconv.c,v 1.29 2013/11/04 20:55:00 ds6peter Exp $
- * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6logconv.c,v 1.35 2014/05/11 09:49:38 ds6peter Exp $
+ * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile conversions
@@ -37,9 +37,11 @@
 #include "libeui64.h"
 #include "libieee.h"
 
+#include "../databases/lib/libipv6calc_db_wrapper.h"
+
 #define LINEBUFFER	16384
 
-long int ipv6calc_debug = 0;
+long int ipv6calc_debug = 0; // ipv6calc_debug usage ok
 int flag_nocache = 0;
 
 /* supported output types:
@@ -49,7 +51,7 @@ int flag_nocache = 0;
  */
 
 /* prototypes */
-static int converttoken(char *result, const char *token, const long int outputtype, const int flag_skipunknown);
+static int converttoken(char *result, const size_t resultstring_length, const char *token, const long int outputtype, const int flag_skipunknown);
 static void lineparser(const long int outputtype);
 
 
@@ -64,6 +66,9 @@ static long int cache_lru_key_outputtype[CACHE_LRU_SIZE];
 static char     cache_lru_value[CACHE_LRU_SIZE][NI_MAXHOST];
 static long int cache_lru_statistics[CACHE_LRU_SIZE];
 
+int feature_reg = 0;
+int feature_ieee = 0;
+
 /**************************************************/
 /* main */
 int main(int argc,char *argv[]) {
@@ -93,7 +98,7 @@ int main(int argc,char *argv[]) {
 	};
 
 	/* initialize debug value from environment for bootstrap debugging */
-	ipv6calc_debug_from_env();
+	ipv6calc_debug_from_env(); // ipv6calc_debug usage ok
 
 	/* add options */
 	ipv6calc_options_add_common_basic(shortopts, sizeof(shortopts), longopts, &longopts_maxentries);
@@ -106,9 +111,7 @@ int main(int argc,char *argv[]) {
 
 	/* Fetch the command-line arguments. */
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "%s/%s: Parsing option: 0x%08x\n", __FILE__, __func__, i);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6logconv_general, "Parsing option: 0x%08x", i);
 
 		/* catch common options */
 		result = ipv6calcoptions_common_basic(i, optarg, longopts);
@@ -174,6 +177,21 @@ int main(int argc,char *argv[]) {
 	argv += optind;
 	argc -= optind;
 
+	/* initialise database wrapper */
+	result = libipv6calc_db_wrapper_init();
+	if (result != 0) {
+		exit(EXIT_FAILURE);
+	};
+
+	/* check for basic database support */
+	if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_REGISTRY | IPV6CALC_DB_IPV6_TO_REGISTRY | IPV6CALC_DB_CC_TO_REGISTRY) == 1) {
+		feature_reg = 1;
+	};
+
+	if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IEEE_TO_INFO) == 1) {
+		feature_ieee = 1;
+	};
+
 	/* print help handling */
 	if (command == CMD_printhelp) {
 		ipv6logconv_printhelp();
@@ -183,13 +201,22 @@ int main(int argc,char *argv[]) {
 		exit(EXIT_FAILURE);
 	};
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "Debug value:%lx  command:%lx  inputtype:%lx   outputtype:%lx  action:%lx\n", (unsigned long) ipv6calc_debug, command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action); 
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6logconv_general, "Debug value:%lx  command:%lx  inputtype:%lx   outputtype:%lx  action:%lx", (unsigned long) ipv6calc_debug, command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action); // ipv6calc_debug usage ok
 	
 	/* do work depending on selection */
 	if (command == CMD_printversion) {
 		printversion();
+		exit(EXIT_SUCCESS);
+	};
+
+	if ((outputtype == FORMAT_any) && ((feature_reg == 0) || (feature_ieee == 0))) {
+		fprintf(stderr, "Basic databases are missing for conversion and outputtype 'any'\n");
+		exit(EXIT_FAILURE);
+	} else if ((outputtype == FORMAT_ouitype) && (feature_ieee == 0)) {
+		fprintf(stderr, "Basic databases are missing for conversion and outputtype 'ouitype'\n");
+		exit(EXIT_FAILURE);
+	} else if ((outputtype == FORMAT_addrtype) && (feature_reg == 0)) {
+		fprintf(stderr, "Basic databases are missing for conversion and outputtype 'addrtype'\n");
 		exit(EXIT_FAILURE);
 	};
 
@@ -233,9 +260,7 @@ static void lineparser(const long int outputtype) {
 			};
 		};
 		
-		if (ipv6calc_debug == 1) {
-			fprintf(stderr, "Line: %d\r", linecounter);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "Line counter: %d", linecounter);
 
 		if (strlen(linebuffer) >= LINEBUFFER) {
 			fprintf(stderr, "Line too long: %d\n", linecounter);
@@ -262,15 +287,15 @@ static void lineparser(const long int outputtype) {
 			continue;
 		};
 
-		snprintf(token, sizeof(token) - 1, "%s", charptr);
+		snprintf(token, sizeof(token), "%s", charptr);
 		
 		DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "Token 1: '%s'", token);
 		
 		/* call converter now */
 		if ( outputtype == FORMAT_any ) {
-			retval = converttoken(resultstring, charptr, FORMAT_addrtype, 0);
+			retval = converttoken(resultstring, sizeof(resultstring), charptr, FORMAT_addrtype, 0);
 		} else {
-			retval = converttoken(resultstring, charptr, outputtype, 1);
+			retval = converttoken(resultstring, sizeof(resultstring), charptr, outputtype, 1);
 		};
 
 		if (retval != 0) {
@@ -318,7 +343,7 @@ static void lineparser(const long int outputtype) {
 			};
 			
 			DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "Token 3: '%s'", charptr);
-			retval = converttoken(resultstring, token, FORMAT_ouitype, 0);
+			retval = converttoken(resultstring, sizeof(resultstring), token, FORMAT_ouitype, 0);
 			/* print result */
 			printf(" %s", resultstring);
 		};
@@ -348,11 +373,11 @@ END_line:
 /*
  * Convert token
  */
-static int converttoken(char *resultstring, const char *token, const long int outputtype, const int flag_skipunknown) {
+static int converttoken(char *resultstring, const size_t resultstring_length, const char *token, const long int outputtype, const int flag_skipunknown) {
 	long int inputtype = -1;
-	int retval = 1, i;
+	int retval = 1, i, registry;
 	uint32_t typeinfo, typeinfo_test;
-	char tempstring[NI_MAXHOST], temp2string[NI_MAXHOST];
+	char tempstring[NI_MAXHOST];
 	ipv6calc_macaddr macaddr;
 
 	/* used structures */
@@ -371,17 +396,13 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 	/* use cache ? */
 	if (flag_nocache == 0 && cache_lru_max > 0) {
 		/* check last seen one first */
-		if ((ipv6calc_debug & 0x4) != 0) {
-			fprintf(stderr, "LRU cache: look for key=%s\n", token);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "LRU cache: look for key=%s", token);
 
 		if (cache_lru_key_outputtype[cache_lru_last - 1] == outputtype) {
 			if (strcmp(cache_lru_key_token[cache_lru_last - 1], token) == 0) {
-				snprintf(resultstring, LINEBUFFER - 1, "%s", cache_lru_value[cache_lru_last - 1]);
+				snprintf(resultstring, resultstring_length, "%s", cache_lru_value[cache_lru_last - 1]);
 				cache_lru_statistics[0]++;
-				if ((ipv6calc_debug & 0x4) != 0) {
-					fprintf(stderr, "LRU cache: hit last line=%d key_token=%s key_outputtype=%lx value=%s\n", cache_lru_last - 1, token, outputtype, resultstring);
-				};
+				DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "LRU cache: hit last line=%d key_token=%s key_outputtype=%lx value=%s", cache_lru_last - 1, token, outputtype, resultstring);
 				return (0);
 			};
 		} else {
@@ -390,11 +411,9 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 				for (i = cache_lru_last - 1; i > 0; i--) {
 					if (cache_lru_key_outputtype[i - 1] == outputtype) {
 						if (strcmp(cache_lru_key_token[i - 1], token) == 0) {
-							snprintf(resultstring, LINEBUFFER - 1, "%s", cache_lru_value[i - 1]);
+							snprintf(resultstring, resultstring_length, "%s", cache_lru_value[i - 1]);
 							cache_lru_statistics[cache_lru_last - i]++;
-							if ((ipv6calc_debug & 0x4) != 0) {
-								fprintf(stderr, "LRU cache: hit line=%d key_token=%s key_outputtype=%lx value=%s\n", i - 1, token, outputtype, resultstring);
-							};
+							DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "LRU cache: hit line=%d key_token=%s key_outputtype=%lx value=%s", i - 1, token, outputtype, resultstring);
 							return (0);
 						};
 					};
@@ -405,11 +424,9 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 				for (i = cache_lru_max; i > cache_lru_last; i--) {
 					if (cache_lru_key_outputtype[i - 1] == outputtype) {
 						if (strcmp(cache_lru_key_token[i - 1], token) == 0) {
-							snprintf(resultstring, LINEBUFFER - 1, "%s", cache_lru_value[i - 1]);
+							snprintf(resultstring, resultstring_length, "%s", cache_lru_value[i - 1]);
 							cache_lru_statistics[cache_lru_max - i + cache_lru_last]++;
-							if ((ipv6calc_debug & 0x4) != 0) {
-								fprintf(stderr, "LRU cache: hit line=%d key_token=%s key_outputtype=%lx value=%s\n", i - 1, token, outputtype, resultstring);
-							};
+							DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "LRU cache: hit line=%d key_token=%s key_outputtype=%lx value=%s", i - 1, token, outputtype, resultstring);
 							return (0);
 						};
 					};
@@ -426,28 +443,28 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 	/* autodetection */
 	inputtype = libipv6calc_autodetectinput(token);
 
-	if (ipv6calc_debug != 0) {
+	DEBUGSECTION_BEGIN(DEBUG_ipv6logconv_processing)
 		if (inputtype >= 0) {
-			for (i = 0; i < (int) (sizeof(ipv6calc_formatstrings) / sizeof(ipv6calc_formatstrings[0])); i++) {
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
 				if (inputtype == ipv6calc_formatstrings[i].number) {
-					fprintf(stderr, "%s/%s: Found type: %s\n", __FILE__, __func__, ipv6calc_formatstrings[i].token);
+					DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "Found type: %s", ipv6calc_formatstrings[i].token);
 				};
 				break;
 			};
 		} else {
-			fprintf(stderr, "%s/%s: Input type unknown\n", __FILE__, __func__);
+			DEBUGPRINT_NA(DEBUG_ipv6logconv_processing, "Input type unknown");
 			return (1);
 		};
-	};
+	DEBUGSECTION_END
 
 	/* proceed input depending on type */	
 	switch (inputtype) {
 		case FORMAT_ipv6addr:
-			retval = addr_to_ipv6addrstruct(token, resultstring, &ipv6addr);
+			retval = addr_to_ipv6addrstruct(token, resultstring, sizeof(resultstring), &ipv6addr);
 			break;
 
 		case FORMAT_ipv4addr:
-			retval = addr_to_ipv4addrstruct(token, resultstring, &ipv4addr);
+			retval = addr_to_ipv4addrstruct(token, resultstring, sizeof(resultstring), &ipv4addr);
 			break;
 	};
 
@@ -460,14 +477,15 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 	switch (outputtype) {
 		case FORMAT_addrtype:
 			if (ipv6addr.flag_valid == 1) {
-				snprintf(resultstring, LINEBUFFER - 1, "ipv6-addr.addrtype.ipv6calc");
+				DEBUGPRINT_NA(DEBUG_ipv6logconv_processing, "is IPv6 address");
+				snprintf(resultstring, resultstring_length, "ipv6-addr.addrtype.ipv6calc");
 
 				/* check for registry */
 				typeinfo = ipv6addr_gettype(&ipv6addr);
 
 				/* scope of IPv6 address */
 				/* init retval */
-				for (i = 0; i < (size_t) (sizeof(ipv6calc_ipv6addrtypestrings) / sizeof(ipv6calc_ipv6addrtypestrings[0])); i++) {
+				for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++) {
 					if ( ipv6calc_ipv6addrtypestrings[i].number == IPV6_ADDR_ANY ) {
 						retval = i;
 						break;
@@ -476,19 +494,19 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 				typeinfo_test = typeinfo & (IPV6_NEW_ADDR_AGU | IPV6_ADDR_LINKLOCAL | IPV6_ADDR_SITELOCAL | IPV6_ADDR_MAPPED | IPV6_ADDR_COMPATv4 | IPV6_ADDR_ULUA);
 				if ( typeinfo_test != 0 ) {
 					/* get string */
-					for (i = 0; i < (size_t) (sizeof(ipv6calc_ipv6addrtypestrings) / sizeof(ipv6calc_ipv6addrtypestrings[0])); i++) {
+					for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++) {
 						if ( (typeinfo_test & ipv6calc_ipv6addrtypestrings[i].number) != 0 ) {
 							retval = i;
 							break;
 						};
 					};
 				};
-				snprintf(tempstring, sizeof(tempstring) - 1, "%s.%s", ipv6calc_ipv6addrtypestrings[retval].token, resultstring);
-				snprintf(resultstring, LINEBUFFER - 1,"%s", tempstring);
+				snprintf(tempstring, sizeof(tempstring), "%s.%s", ipv6calc_ipv6addrtypestrings[retval].token, resultstring);
+				snprintf(resultstring, resultstring_length,"%s", tempstring);
 
 				/* type of global IPv6 address */
 				/* init retval */
-				for (i = 0; i < (size_t) (sizeof(ipv6calc_ipv6addrtypestrings) / sizeof(ipv6calc_ipv6addrtypestrings[0])); i++) {
+				for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++) {
 					if ( ipv6calc_ipv6addrtypestrings[i].number == IPV6_ADDR_ANY ) {
 						retval = i;
 						break;
@@ -497,29 +515,29 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 				typeinfo_test = typeinfo & (IPV6_NEW_ADDR_6TO4 | IPV6_NEW_ADDR_6BONE | IPV6_NEW_ADDR_PRODUCTIVE);
 				if ( typeinfo_test != 0 ) {
 					if ((typeinfo & IPV6_NEW_ADDR_TEREDO) != 0) {
-						snprintf(tempstring, sizeof(tempstring) - 1, "teredo.%s", resultstring);
-						snprintf(resultstring, LINEBUFFER - 1, "%s", tempstring);
+						snprintf(tempstring, sizeof(tempstring), "teredo.%s", resultstring);
+						snprintf(resultstring, resultstring_length, "%s", tempstring);
 					} else {
 						/* get string */
-						for (i = 0; i < (size_t) (sizeof(ipv6calc_ipv6addrtypestrings) / sizeof(ipv6calc_ipv6addrtypestrings[0])); i++) {
+						for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++) {
 							if ( (typeinfo_test & ipv6calc_ipv6addrtypestrings[i].number) != 0 ) {
 								retval = i;
 								break;
 							};
 						};
-						snprintf(tempstring, sizeof(tempstring) - 1, "%s.%s", ipv6calc_ipv6addrtypestrings[retval].token, resultstring);
-						snprintf(resultstring, LINEBUFFER - 1, "%s", tempstring);
+						snprintf(tempstring, sizeof(tempstring), "%s.%s", ipv6calc_ipv6addrtypestrings[retval].token, resultstring);
+						snprintf(resultstring, resultstring_length, "%s", tempstring);
 					};
 				};
 
 				/* registry of IPv6 address */
 				if ( ( (typeinfo & (IPV6_NEW_ADDR_6BONE | IPV6_NEW_ADDR_PRODUCTIVE) ) != 0) && ( (typeinfo & (IPV6_NEW_ADDR_TEREDO)) == 0)) {
-					retval = libipv6addr_get_registry_string(&ipv6addr, temp2string);
-					if ( retval == 0 ) {
-						snprintf(tempstring, sizeof(tempstring) - 1, "%s.%s", temp2string, resultstring);
-						snprintf(resultstring, LINEBUFFER - 1, "%s", tempstring);
-					};
+					registry = libipv6addr_registry_num_by_addr(&ipv6addr);
+					snprintf(tempstring, sizeof(tempstring), "%s.%s", libipv6calc_registry_string_by_num(registry), resultstring);
+					snprintf(resultstring, resultstring_length, "%s", tempstring);
 				} else if ( (typeinfo & (IPV6_NEW_ADDR_6TO4 | IPV6_ADDR_MAPPED | IPV6_ADDR_COMPATv4 | IPV6_NEW_ADDR_TEREDO)) != 0 ) {
+					DEBUGPRINT_NA(DEBUG_ipv6logconv_processing, "IPv6 has IPv4 included");
+
 					/* fill IPv4 address */
 					if ( (typeinfo & (IPV6_ADDR_MAPPED | IPV6_ADDR_COMPATv4)) != 0 ) {
 						for (i = 0; i <= 3; i++) {
@@ -539,24 +557,22 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 						exit(EXIT_FAILURE);
 					};
 
-					retval = libipv4addr_get_registry_string(&ipv4addr, temp2string);
-					if ( retval == 0 ) {
-						/* IPv4 registry */
-						snprintf(tempstring, sizeof(tempstring) - 1, "%s.%s", temp2string, resultstring);
-						snprintf(resultstring, LINEBUFFER - 1, "%s", tempstring);
-					};
+					ipv4addr.scope = ipv4addr_gettype(&ipv4addr);
+
+					/* IPv4 registry */
+					registry = libipv4addr_registry_num_by_addr(&ipv4addr);
+					snprintf(tempstring, sizeof(tempstring), "%s.%s", libipv6calc_registry_string_by_num(registry), resultstring);
+					snprintf(resultstring, resultstring_length, "%s", tempstring);
 				};
 			} else if (ipv4addr.flag_valid == 1) {
-				snprintf(resultstring, LINEBUFFER - 1, "ipv4-addr.addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "ipv4-addr.addrtype.ipv6calc");
 
-				retval = libipv4addr_get_registry_string(&ipv4addr, temp2string);
-				if ( retval == 0 ) {
-					/* IPv4 registry */
-					snprintf(tempstring, sizeof(tempstring) - 1, "%s.%s", temp2string, resultstring);
-					snprintf(resultstring, LINEBUFFER - 1, "%s", tempstring);
-				};
+				/* IPv4 registry */
+				registry = libipv4addr_registry_num_by_addr(&ipv4addr);
+				snprintf(tempstring, sizeof(tempstring), "%s.%s", libipv6calc_registry_string_by_num(registry), resultstring);
+				snprintf(resultstring, resultstring_length, "%s", tempstring);
 			} else {
-				snprintf(resultstring, LINEBUFFER - 1, "reverse-lookup-successful.addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "reverse-lookup-successful.addrtype.ipv6calc");
 			};
 			break;
 
@@ -565,7 +581,7 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 				if (flag_skipunknown != 0) {
 					return (1);
 				} else {
-					snprintf(resultstring, LINEBUFFER - 1, "not-ipv6.ouitype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "not-ipv6.ouitype.ipv6calc");
 					return (0);
 				};
 		       	};
@@ -577,7 +593,7 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 				if (flag_skipunknown != 0) {
 					return (1);
 				} else {
-					snprintf(resultstring, LINEBUFFER - 1, "unresolvable.ouitype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "unresolvable.ouitype.ipv6calc");
 					return (0);
 				};
 		       	};
@@ -590,32 +606,32 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 				macaddr.addr[4] = ipv6addr_getoctet(&ipv6addr, 14);
 				macaddr.addr[5] = ipv6addr_getoctet(&ipv6addr, 15);
 
-				retval = libieee_get_short_vendor_string(resultstring, &macaddr);
+				retval = libipv6calc_db_wrapper_ieee_vendor_string_short_by_macaddr(resultstring, sizeof(resultstring), &macaddr);
 				if (retval != 0) {
 					if (flag_skipunknown != 0) {
 						return (1);
 					} else {
-						snprintf(resultstring, LINEBUFFER - 1, "unresolvable.ouitype.ipv6calc");
+						snprintf(resultstring, resultstring_length, "unresolvable.ouitype.ipv6calc");
 						return (0);
 					};
 				};
 				if (strlen(resultstring) == 0) {
-					snprintf(resultstring, LINEBUFFER - 1, "unknown.ouitype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "unknown.ouitype.ipv6calc");
 				} else {
-					snprintf(tempstring, sizeof(tempstring) - 1, "%s.ouitype.ipv6calc", resultstring);
-					snprintf(resultstring, LINEBUFFER - 1, "%s", tempstring);
+					snprintf(tempstring, sizeof(tempstring), "%s.ouitype.ipv6calc", resultstring);
+					snprintf(resultstring, resultstring_length, "%s", tempstring);
 				};
 			} else {
 				if ( (typeinfo & IPV6_NEW_ADDR_6TO4_MICROSOFT) != 0 ) {
-					snprintf(resultstring, LINEBUFFER - 1, "6to4-microsoft.ouitype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "6to4-microsoft.ouitype.ipv6calc");
 				} else if ( (typeinfo & IPV6_NEW_ADDR_IID_ISATAP) != 0 ) {
-					snprintf(resultstring, LINEBUFFER - 1, "ISATAP.ouitype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "ISATAP.ouitype.ipv6calc");
 				} else if ( (typeinfo & IPV6_NEW_ADDR_IID_RANDOM) != 0 ) {
-					snprintf(resultstring, LINEBUFFER - 1, "local-scope-random.ouitype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "local-scope-random.ouitype.ipv6calc");
 				} else if ( (typeinfo & IPV6_NEW_ADDR_TEREDO) != 0 ) {
-					snprintf(resultstring, LINEBUFFER - 1, "local-scope-teredo.ouitype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "local-scope-teredo.ouitype.ipv6calc");
 				} else {
-					snprintf(resultstring, LINEBUFFER - 1, "local-scope.ouitype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "local-scope.ouitype.ipv6calc");
 				};
 			};
 			break;
@@ -625,7 +641,7 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 				if (flag_skipunknown != 0) {
 					return (1);
 				} else {
-					snprintf(resultstring, LINEBUFFER - 1, "not-ipv6.ipv6addrtype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "not-ipv6.ipv6addrtype.ipv6calc");
 					return (0);
 				};
 		       	};
@@ -633,29 +649,29 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 			typeinfo = ipv6addr_gettype(&ipv6addr);
 
 		       	if ( (typeinfo & IPV6_ADDR_LINKLOCAL) != 0 ) {
-				snprintf(resultstring, LINEBUFFER - 1, "link-local.ipv6addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "link-local.ipv6addrtype.ipv6calc");
 			} else if ( (typeinfo & IPV6_ADDR_SITELOCAL) != 0 ) {
-				snprintf(resultstring, LINEBUFFER - 1, "site-local.ipv6addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "site-local.ipv6addrtype.ipv6calc");
 			} else if ( (typeinfo & IPV6_ADDR_ULUA) != 0 ) {
-				snprintf(resultstring, LINEBUFFER - 1, "unique-local.ipv6addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "unique-local.ipv6addrtype.ipv6calc");
 			} else if ( (typeinfo & IPV6_NEW_ADDR_TEREDO) != 0 ) {
 				if ( (typeinfo & IPV6_NEW_ADDR_6BONE) != 0 ) {
-					snprintf(resultstring, LINEBUFFER - 1, "teredo.6bone-global.ipv6addrtype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "teredo.6bone-global.ipv6addrtype.ipv6calc");
 				} else {
-					snprintf(resultstring, LINEBUFFER - 1, "teredo.unknown-global.ipv6addrtype.ipv6calc");
+					snprintf(resultstring, resultstring_length, "teredo.unknown-global.ipv6addrtype.ipv6calc");
 				};
 			} else if ( (typeinfo & IPV6_NEW_ADDR_6BONE) != 0 ) {
-				snprintf(resultstring, LINEBUFFER - 1, "6bone-global.ipv6addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "6bone-global.ipv6addrtype.ipv6calc");
 			} else if ( (typeinfo & IPV6_NEW_ADDR_6TO4) != 0 ) {
-				snprintf(resultstring, LINEBUFFER - 1, "6to4-global.ipv6addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "6to4-global.ipv6addrtype.ipv6calc");
 			} else if ( (typeinfo & IPV6_NEW_ADDR_PRODUCTIVE) != 0 ) {
-				snprintf(resultstring, LINEBUFFER - 1, "productive-global.ipv6addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "productive-global.ipv6addrtype.ipv6calc");
 			} else if ( (typeinfo & IPV6_ADDR_MAPPED) != 0 ) {
-				snprintf(resultstring, LINEBUFFER - 1, "mapped-ipv4.ipv6addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "mapped-ipv4.ipv6addrtype.ipv6calc");
 			} else if ( (typeinfo & IPV6_ADDR_COMPATv4) != 0 ) {
-				snprintf(resultstring, LINEBUFFER - 1, "compat-ipv4.ipv6addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "compat-ipv4.ipv6addrtype.ipv6calc");
 			} else {
-				snprintf(resultstring, LINEBUFFER - 1, "unknown-ipv6.ipv6addrtype.ipv6calc");
+				snprintf(resultstring, resultstring_length, "unknown-ipv6.ipv6addrtype.ipv6calc");
 			};
 			break;
 
@@ -682,9 +698,7 @@ static int converttoken(char *resultstring, const char *token, const long int ou
 		snprintf(cache_lru_key_token[cache_lru_last - 1], NI_MAXHOST - 1, "%s", token);
 		cache_lru_key_outputtype[cache_lru_last - 1] = outputtype;
 		snprintf(cache_lru_value[cache_lru_last - 1], NI_MAXHOST - 1, "%s", resultstring);
-		if ((ipv6calc_debug & 0x4) != 0) {
-			fprintf(stderr, "LRU cache: fill line=%d key_token=%s key_outputtype=%lx value=%s\n", cache_lru_last - 1, cache_lru_key_token[cache_lru_last - 1], cache_lru_key_outputtype[cache_lru_last - 1], cache_lru_value[cache_lru_last - 1]);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6logconv_processing, "LRU cache: fill line=%d key_token=%s key_outputtype=%lx value=%s", cache_lru_last - 1, cache_lru_key_token[cache_lru_last - 1], cache_lru_key_outputtype[cache_lru_last - 1], cache_lru_value[cache_lru_last - 1]);
 	};
 
 	return (0);
