@@ -2,8 +2,8 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6logconv.sh
-# Version    : $Id: test_ipv6logconv.sh,v 1.9 2013/09/20 06:17:52 ds6peter Exp $
-# Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: test_ipv6logconv.sh,v 1.11 2014/05/20 18:00:34 ds6peter Exp $
+# Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test program for "ipv6logconv"
 
@@ -20,6 +20,8 @@ if [ $? -ne 1 ]; then
 	exit 1
 fi
 
+source ../ipv6calc/test_scenarios.sh
+
 testscenarios() {
 # Address
 cat <<END | grep -v "^#"
@@ -86,6 +88,13 @@ END_CACHE
 ## main ##
 echo "Run 'ipv6logconv' function tests..." >&2
 
+if ./ipv6logconv -v | grep -w "CONV_REG" | grep -w "CONV_IEEE"; then
+	true
+else
+	echo "NOTICE : ipv6logconv tests skipped, at least one required database feature is missing"
+	exit 0
+fi
+
 if [ "$1" != "bulk" ]; then
 	testscenarios | grep -v "^#" | while read line; do
 		echo
@@ -96,7 +105,7 @@ if [ "$1" != "bulk" ]; then
 			echo "Error executing 'ipv6logconv'!" >&2
 			exit 1
 		fi
-	done
+	done || exit 1
 	echo 
 else
 	shift
@@ -117,6 +126,15 @@ else
 	echo
 fi
 
+echo "INFO  : test scenario with huge amount of addresses..."
+testscenario_hugelist ipv4 | awk '{ print $1 " token2 token3" }' | ./ipv6logconv -q --out any -q >/dev/null
+if [ $? -ne 0 ]; then
+	echo "ERROR : exit code <> 0"
+	exit 1
+fi
+
+echo "INFO  : test scenario with huge amount of addresses: OK"
+
 if [ $? -eq 0 ]; then
 	echo "All tests were successfully done!" >&2
 fi
