@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.c
- * Version    : $Id: ipv6calchelp.c,v 1.50 2013/11/02 17:05:11 ds6peter Exp $
- * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calchelp.c,v 1.57 2014/05/11 09:49:38 ds6peter Exp $
+ * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Help library
@@ -19,11 +19,6 @@
 #include "config.h"
 
 #include "libieee.h"
-#include "databases/ieee-oui/dbieee_oui.h"
-#include "databases/ieee-iab/dbieee_iab.h"
-#include "databases/ieee-oui36/dbieee_oui36.h"
-#include "databases/ipv4-assignment/dbipv4addr_assignment.h"
-#include "databases/ipv6-assignment/dbipv6addr_assignment.h"
 #include "databases/lib/libipv6calc_db_wrapper.h"
 #include "databases/lib/libipv6calc_db_wrapper_GeoIP.h"
 #include "databases/lib/libipv6calc_db_wrapper_IP2Location.h"
@@ -92,7 +87,7 @@ void printhelp_inputtypes(const uint32_t formatoptions) {
 	};
 
 	/* look for longest type definition */
-	for (j = 0; j < (int) (sizeof(ipv6calc_formatstrings) / sizeof(ipv6calc_formatstrings[0])); j++) {
+	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
 		if (strlen(ipv6calc_formatstrings[j].token) > maxlen) {
 			maxlen = strlen(ipv6calc_formatstrings[j].token);
 		};
@@ -104,28 +99,22 @@ void printhelp_inputtypes(const uint32_t formatoptions) {
 	};
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) {	
-		snprintf(printformatstring, sizeof(printformatstring) - 1, "  %%-%ds : %%s\n", (int) maxlen);
+		snprintf(printformatstring, sizeof(printformatstring), "  %%-%ds : %%s\n", (int) maxlen);
 	} else {
-		snprintf(printformatstring, sizeof(printformatstring) - 1, "%%-%ds\n", (int) maxlen);
+		snprintf(printformatstring, sizeof(printformatstring), "%%-%ds\n", (int) maxlen);
 	}
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "Format string: %s\n", printformatstring);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format string: %s", printformatstring);
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) fprintf(stderr, "\n Available input types:\n");
 
 	/* run through matrix */
 	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatmatrix); i++) {
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "Row %d: %08x - %08x\n", i, (unsigned int) ipv6calc_formatmatrix[i][0], (unsigned int) ipv6calc_formatmatrix[i][1]);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Row %d: %08x - %08x", i, (unsigned int) ipv6calc_formatmatrix[i][0], (unsigned int) ipv6calc_formatmatrix[i][1]);
 		if (ipv6calc_formatmatrix[i][1] != 0) {
 			/* available for input, look for name now */
 			for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "Format-Row %d: %08x - %s - %s\n", j, (unsigned int) ipv6calc_formatstrings[j].number, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
-				};
+				DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format-Row %d: %08x - %s - %s", j, (unsigned int) ipv6calc_formatstrings[j].number, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
 				if (ipv6calc_formatstrings[j].number == ipv6calc_formatmatrix[i][0]) {
 					if ((formatoptions & FORMATOPTION_machinereadable) == 0) {	
 						fprintf(stderr, printformatstring, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
@@ -165,14 +154,12 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 	};
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) {	
-		snprintf(printformatstring, sizeof(printformatstring) - 1, "  %%-%ds : %%s\n", (int) maxlen);
+		snprintf(printformatstring, sizeof(printformatstring), "  %%-%ds : %%s\n", (int) maxlen);
 	} else {
-		snprintf(printformatstring, sizeof(printformatstring) - 1, "%%-%ds\n", (int) maxlen);
+		snprintf(printformatstring, sizeof(printformatstring), "%%-%ds\n", (int) maxlen);
 	};
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "Format string: %s\n", printformatstring);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format string: %s", printformatstring);
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) {
 		if ( (inputtype & ~ (FORMAT_auto | FORMAT_any) ) != 0 ) {
@@ -184,9 +171,7 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 
 	/* run through matrix */
 	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "Format-Row %d: %08x - %s - %s\n", j, (unsigned int) ipv6calc_formatstrings[j].number, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format-Row %d: %08x - %s - %s", j, (unsigned int) ipv6calc_formatstrings[j].number, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
 
 		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatmatrix); i++) {
 			if ( (inputtype & ~ (FORMAT_auto | FORMAT_any) ) != 0 ) {
@@ -196,9 +181,7 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 				};
 			};
 		
-			if (ipv6calc_debug != 0) {
-				fprintf(stderr, "Row %d: %08x - %08x\n", i, (unsigned int) ipv6calc_formatmatrix[i][0], (unsigned int) ipv6calc_formatmatrix[i][1]);
-			};
+			DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Row %d: %08x - %08x", i, (unsigned int) ipv6calc_formatmatrix[i][0], (unsigned int) ipv6calc_formatmatrix[i][1]);
 
 			if ((ipv6calc_formatmatrix[i][1] & ipv6calc_formatstrings[j].number) != 0) {
 				/* available for output, look for name now */
@@ -214,7 +197,7 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) {
 		fprintf(stderr, "\n For examples and available format options use:\n");
-		fprintf(stderr, "    --out <type> --examples\n");
+		fprintf(stderr, "    -O|--out <type> --examples\n");
 		fprintf(stderr, "\n");
 	};
 };
@@ -232,7 +215,7 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 	};
 
 	/* look for longest type definition */
-	for (j = 0; j < (int) (sizeof(ipv6calc_actionstrings) / sizeof(ipv6calc_actionstrings[0])); j++) {
+	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_actionstrings); j++) {
 		if (strlen(ipv6calc_actionstrings[j].token) > maxlen) {
 			maxlen = strlen(ipv6calc_actionstrings[j].token);
 		};
@@ -244,24 +227,20 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 	};
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) {
-		snprintf(printformatstring, sizeof(printformatstring) - 1, "  %%-%ds : %%s\n", (int) maxlen);
+		snprintf(printformatstring, sizeof(printformatstring), "  %%-%ds : %%s\n", (int) maxlen);
 	} else {
-		snprintf(printformatstring, sizeof(printformatstring) - 1, "%%-%ds\n", (int) maxlen);
+		snprintf(printformatstring, sizeof(printformatstring), "%%-%ds\n", (int) maxlen);
 	};
 
-	snprintf(printformatstring2, sizeof(printformatstring2) - 1, "  %%-%ds%%s\n", (int) maxlen + 4);
-	snprintf(printformatstring3, sizeof(printformatstring3) - 1, "  %%-%ds--%%s", (int) maxlen + 5);
+	snprintf(printformatstring2, sizeof(printformatstring2), "  %%-%ds%%s\n", (int) maxlen + 4);
+	snprintf(printformatstring3, sizeof(printformatstring3), "  %%-%ds--%%s", (int) maxlen + 5);
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "Format string: %s\n", printformatstring);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format string: %s", printformatstring);
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) fprintf(stderr, "\n Available action types:\n");
 
 	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_actionstrings); j++) {
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "Format-Row %d: %08x - %s - %s\n", j, (unsigned int) ipv6calc_actionstrings[j].number, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format-Row %d: %08x - %s - %s", j, (unsigned int) ipv6calc_actionstrings[j].number, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
 
 		if ((formatoptions & FORMATOPTION_machinereadable) == 0) {
 			fprintf(stderr, printformatstring, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
@@ -273,9 +252,7 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 
 				/* search for defined options */
 				for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_actionoptionmap); i++) {
-					if (ipv6calc_debug != 0) {
-						fprintf(stderr, "Option %d\n", i);
-					};
+					DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Option %d", i)
 
 					if (ipv6calc_actionstrings[j].number == ipv6calc_actionoptionmap[i][0]) {
 						if (ipv6calc_actionoptionmap[i][1] == 0) {
@@ -283,9 +260,7 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 							break;
 						};
 						
-						if (ipv6calc_debug != 0) {
-							fprintf(stderr, "Option value: %08x\n", (unsigned int) ipv6calc_actionoptionmap[i][1]);
-						};
+						DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Option value: %08x", (unsigned int) ipv6calc_actionoptionmap[i][1]);
 
 						/* run through options */
 						o = 0;
@@ -320,7 +295,7 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 /* print global common help */
 void printhelp_common(void) {
 	fprintf(stderr, "  [-d|--debug <debug value>] : debug value (bitwise like)\n");
-	fprintf(stderr, "                                can also be set IPV6CALC_DEBUG environment value\n");
+	fprintf(stderr, "                                can also be set by IPV6CALC_DEBUG environment value\n");
 	fprintf(stderr, "  [-v|--version [-v [-v]]]   : version information (2 optional verbose levels)\n");
 	fprintf(stderr, "  [-h|--help|-?]             : this online help\n");
 
@@ -344,18 +319,47 @@ void printhelp_common(void) {
 	return;
 };
 
-void printhelp_oldoptions(const struct option longopts[]) {
+void printhelp_shortcut_options(const struct option longopts[], const s_ipv6calc_longopts_shortopts_map longopts_shortopts_map[]) {
 	int i = 0;
+	int j;
+	char c;
+	const char *info;
 	
-	printversion();
-	printcopyright();
-	fprintf(stderr, " Usage with old style (shortcut) options (going obsolete):\n");
-	fprintf(stderr, "  <shortcut option> [<format option> ...] <input data> [...]\n");
+	fprintf(stderr, "\n");
+	fprintf(stderr, " Usage with shortcut options: <shortcut option> [<format option> ...] <input data>\n");
+	fprintf(stderr, "  for more information and available format options use: <shortcut option> -?|-h|--help\n");
 	fprintf(stderr, "\n");
 
 	while(longopts[i].name != NULL) {
 		if (longopts[i].val >= CMD_shortcut_start && longopts[i].val <= CMD_shortcut_end) {
-			fprintf(stderr, "  --%s\n", longopts[i].name);
+			c = '\0';
+			info = NULL;
+
+			if (longopts_shortopts_map != NULL) {
+				DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Search in longopts_shortopts_map for %08x", longopts[i].val);
+				j = 0;
+				while (longopts_shortopts_map[j].val > 0) {
+					DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Check against longopts_shortopts_map entry %d:%08x", j, longopts_shortopts_map[j].val);
+					if (longopts[i].val == longopts_shortopts_map[j].val) {
+						c = longopts_shortopts_map[j].c;
+						info = longopts_shortopts_map[j].info;
+						break;
+					};
+					j++;
+				};
+			};
+
+			if (c != '\0') {
+				fprintf(stderr, "  -%c|--%s", c, longopts[i].name);
+			} else {
+				fprintf(stderr, "     --%s", longopts[i].name);
+			};
+
+			if (info != NULL) {
+				fprintf(stderr, " (%s)", info);
+			};
+
+			fprintf(stderr, "\n");
 		};
 		i++;
 	};
@@ -552,9 +556,7 @@ void printhelp_output_dispatcher(const uint32_t outputtype) {
 				break;
 			};
 			
-			if (ipv6calc_debug != 0) {
-				fprintf(stderr, "Format value: %08x\n", (unsigned int) ipv6calc_outputformatoptionmap[i][1]);
-			};
+			DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format value: %08x", (unsigned int) ipv6calc_outputformatoptionmap[i][1]);
 			
 			fprintf(stderr, "\n");
 			fprintf(stderr, " Available format options:\n");
@@ -616,11 +618,11 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, "  Available presets (shortcut names) [--anonymize-preset PRESET-NAME]:\n");
 
 			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_anon_set_list); i++) {
-				snprintf(method_name, sizeof(method_name) - 1, "%s", "unknown"); // default
+				snprintf(method_name, sizeof(method_name), "%s", "unknown"); // default
 
 				for (j = 0; j < sizeof(ipv6calc_anon_methods) / sizeof(s_ipv6calc_anon_methods); j++) {
 					if (ipv6calc_anon_methods[j].method == ipv6calc_anon_set_list[i].method) {
-						snprintf(method_name, sizeof(method_name) - 1, "%s", ipv6calc_anon_methods[j].name);
+						snprintf(method_name, sizeof(method_name), "%s", ipv6calc_anon_methods[j].name);
 						break;
 					};
 				};
@@ -660,14 +662,14 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, "\n");
 			fprintf(stderr, "  IPv6 address filter tokens:\n");
 			fprintf(stderr, "   ipv6 ");
-			for (i = 0; i < (int) (sizeof(ipv6calc_ipv6addrtypestrings) / sizeof(ipv6calc_ipv6addrtypestrings[0])); i++ ) {
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
 				fprintf(stderr, " %s", ipv6calc_ipv6addrtypestrings[i].token);
 			};
 			fprintf(stderr, "\n");
 			fprintf(stderr, "\n");
 			fprintf(stderr, "  IPv4 address filter tokens:\n");
 			fprintf(stderr, "   ipv4 ");
-			for (i = 0; i < (int) (sizeof(ipv6calc_ipv4addrtypestrings) / sizeof(ipv6calc_ipv4addrtypestrings[0])); i++ ) {
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
 				fprintf(stderr, " %s", ipv6calc_ipv4addrtypestrings[i].token);
 			};
 			fprintf(stderr, "\n");
