@@ -1,14 +1,15 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.h
- * Version    : $Id: ipv6calchelp.h,v 1.15 2013/10/22 18:59:55 ds6peter Exp $
- * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calchelp.h,v 1.17 2014/04/02 06:11:55 ds6peter Exp $
+ * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for ipv6calchelp.c
  */
 
 #include "ipv6calc_inttypes.h"
+#include "ipv6calcoptions.h"
 
 /* defined in each main program */
 extern void printhelp_info(void);
@@ -27,7 +28,7 @@ extern void printhelp_inputtypes(const uint32_t formatoptions);
 extern void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoptions);
 extern void printhelp_actiontypes(const uint32_t formatoptions, const struct option longopts[]);
 extern void printhelp_common(void);
-extern void printhelp_oldoptions(const struct option longopts[]);
+extern void printhelp_shortcut_options(const struct option longopts[], const s_ipv6calc_longopts_shortopts_map longopts_shortopts_map[]);
 extern void printhelp_output_dispatcher(const uint32_t outputtype);
 extern void printhelp_action_dispatcher(const uint32_t action, const int embedded);
 
