@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6calc.h
- * Version    : $Id: libipv6calc.h,v 1.21 2013/10/31 21:24:46 ds6peter Exp $
- * Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: libipv6calc.h,v 1.24 2014/05/11 09:49:38 ds6peter Exp $
+ * Copyright  : 2001-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc.c
@@ -49,12 +49,14 @@ typedef struct {
 /* Registries */
 #define REGISTRY_APNIC        0x02
 #define REGISTRY_RIPE         0x03
+#define REGISTRY_RIPENCC      0x03
 #define REGISTRY_LACNIC       0x04
 #define REGISTRY_AFRINIC      0x05
 #define REGISTRY_ARIN         0x06
 
 #define REGISTRY_6BONE        0x08
 #define REGISTRY_IANA         0x09
+#define REGISTRY_6TO4         0x0c
 #define REGISTRY_RESERVED     0x0e
 #define REGISTRY_UNKNOWN      0x0f
 
@@ -67,6 +69,7 @@ typedef struct {
         { REGISTRY_RIPE       , "RIPENCC"   },
         { REGISTRY_LACNIC     , "LACNIC"    },
         { REGISTRY_AFRINIC    , "AFRINIC"   },
+        { REGISTRY_6TO4       , "6TO4"      },
         { REGISTRY_RESERVED   , "reserved"  },
         { REGISTRY_UNKNOWN    , "unknown"   }
 };
@@ -105,7 +108,7 @@ extern void string_to_upcase(char *string);
 extern void string_to_lowcase(char *string);
 
 extern void string_to_reverse(char *string);
-extern void string_to_reverse_dotted(char *string);
+extern void string_to_reverse_dotted(char *string, const size_t string_length);
 
 extern uint32_t libipv6calc_autodetectinput(const char *string);
 
