@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : librfc2874.c
- * Version    : $Id: librfc2874.c,v 1.14 2013/05/12 07:23:12 ds6peter Exp $
- * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: librfc2874.c,v 1.16 2014/05/11 09:49:38 ds6peter Exp $
+ * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  RFC 2874 conform addresses (A6/DNAME) bitstring labels
@@ -27,8 +27,7 @@
  * out: *resultstring = result
  * ret: ==0: ok, !=0: error
  */
-#define DEBUG_function_name "librfc2874/addr_to_bitstring"
-int librfc2874_addr_to_bitstring(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const uint32_t formatoptions) {
+int librfc2874_addr_to_bitstring(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const size_t resultstring_length, const uint32_t formatoptions) {
 	int retval = 1;
 	unsigned int nibble;
 	unsigned int noctet, nbit, nnibble, prefixlength, bit_start, bit_end;
@@ -37,12 +36,12 @@ int librfc2874_addr_to_bitstring(const ipv6calc_ipv6addr *ipv6addrp, char *resul
 	if ( (*ipv6addrp).flag_startend_use != 0 ) {
 		/* check start and end */
 		if ( (((*ipv6addrp).bit_start - 1) & 0x03) != 0 ) {
-			snprintf(resultstring, NI_MAXHOST - 1, "Start bit number '%u' not dividable by 4 aren't supported because of non unique representation", (unsigned int) (*ipv6addrp).bit_start);
+			snprintf(resultstring, resultstring_length, "Start bit number '%u' not dividable by 4 aren't supported because of non unique representation", (unsigned int) (*ipv6addrp).bit_start);
 			retval = 1;
 			return (retval);
 		};
 		if ( ((*ipv6addrp).bit_end & 0x03 ) != 0 ) {
-			snprintf(resultstring, NI_MAXHOST - 1, "End bit number '%u' not dividable by 4 aren't supported because of non unique representation", (unsigned int) (*ipv6addrp).bit_end);
+			snprintf(resultstring, resultstring_length, "End bit number '%u' not dividable by 4 aren't supported because of non unique representation", (unsigned int) (*ipv6addrp).bit_end);
 			retval = 1;
 			return (retval);
 		};
@@ -54,9 +53,7 @@ int librfc2874_addr_to_bitstring(const ipv6calc_ipv6addr *ipv6addrp, char *resul
 		bit_end = 128;
 	};
 
-	if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-		fprintf(stderr, "%s: print from start bit to end bit: %u - %u\n", DEBUG_function_name, bit_start, bit_end);
-	};
+	DEBUGPRINT_WA(DEBUG_librfc2874, "print from start bit to end bit: %u - %u", bit_start, bit_end);
 
 	/* print out hex string format */
 	/* 127 is lowest bit, 0 is highest bit */
@@ -71,16 +68,13 @@ int librfc2874_addr_to_bitstring(const ipv6calc_ipv6addr *ipv6addrp, char *resul
 		/* extract nibble */
 		nibble = ( (*ipv6addrp).in6_addr.s6_addr[noctet] & ( 0xf << (unsigned int) (4 * (1 - nnibble)) ) ) >> (unsigned int) ( 4 * (1 - nnibble));
 		
-		if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-			fprintf(stderr, "%s: bit: %u= noctet: %u, nnibble: %u, octet: %02x, value: %x\n", DEBUG_function_name, nbit, noctet, nnibble, (unsigned int) (*ipv6addrp).in6_addr.s6_addr[noctet], nibble);
-		};
+		DEBUGPRINT_WA(DEBUG_librfc2874, "bit: %u= noctet: %u, nnibble: %u, octet: %02x, value: %x", nbit, noctet, nnibble, (unsigned int) (*ipv6addrp).in6_addr.s6_addr[noctet], nibble);
 
-		snprintf(tempstring, sizeof(tempstring) - 1, "%s%x", resultstring, nibble);
-		snprintf(resultstring, NI_MAXHOST - 1, "%s", tempstring);
-		if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-			fprintf(stderr, "%s: Result after step %u (temp): %s\n", DEBUG_function_name, nbit, tempstring);
-			fprintf(stderr, "%s: Result after step %u (resu): %s\n", DEBUG_function_name, nbit, resultstring);
-		};
+		snprintf(tempstring, sizeof(tempstring), "%s%x", resultstring, nibble);
+		snprintf(resultstring, resultstring_length, "%s", tempstring);
+
+		DEBUGPRINT_WA(DEBUG_librfc2874, "Result after step %u (temp): %s", nbit, tempstring);
+		DEBUGPRINT_WA(DEBUG_librfc2874, "Result after step %u (resu): %s", nbit, resultstring);
 	};
 
 	/* add begin and end of label */
@@ -90,31 +84,26 @@ int librfc2874_addr_to_bitstring(const ipv6calc_ipv6addr *ipv6addrp, char *resul
 		prefixlength = 128;
 	};
 	
-	if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-		fprintf(stderr, "%s: Result after expanding: %s\n", DEBUG_function_name, tempstring);
-	};
+	DEBUGPRINT_WA(DEBUG_librfc2874, "Result after expanding: %s", tempstring);
 	
 	if ( bit_start != 1 ) {
-		snprintf(tempstring, sizeof(tempstring) - 1,  "%s/%u]", resultstring, prefixlength);
+		snprintf(tempstring, sizeof(tempstring),  "%s/%u]", resultstring, prefixlength);
 	} else {
-		snprintf(tempstring, sizeof(tempstring) - 1, "%s/%u].ip6.arpa.", resultstring, prefixlength);
+		snprintf(tempstring, sizeof(tempstring), "%s/%u].ip6.arpa.", resultstring, prefixlength);
 	};
 	
 	if ( (formatoptions & FORMATOPTION_printuppercase) != 0 ) {
 		string_to_upcase(tempstring);
 	};
 
-	snprintf(resultstring, NI_MAXHOST - 1, "\\[x%s", tempstring);
+	snprintf(resultstring, resultstring_length, "\\[x%s", tempstring);
 
-	if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-		fprintf(stderr, "%s: Final result: %s\n", DEBUG_function_name, resultstring);
-	};
+	DEBUGPRINT_WA(DEBUG_librfc2874, "Final result: %s", resultstring);
 
 	retval = 0;
 
 	return (retval);
 };
-#undef DEBUG_function_name
 
 
 /*
@@ -124,8 +113,7 @@ int librfc2874_addr_to_bitstring(const ipv6calc_ipv6addr *ipv6addrp, char *resul
  * mod: *ipv6addrp = IPv6 address structure
  * ret: ==0: ok, !=0: error
  */
-#define DEBUG_function_name "librfc2874/bitstring_to_ipv6addrstruct"
-int librfc2874_bitstring_to_ipv6addrstruct(const char *inputstring, ipv6calc_ipv6addr *ipv6addrp, char *resultstring) {
+int librfc2874_bitstring_to_ipv6addrstruct(const char *inputstring, ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const size_t resultstring_length) {
 	int retval = 1;
 	char tempstring[NI_MAXHOST], tempstring2[NI_MAXHOST];
 	unsigned int nibblecounter = 0;
@@ -136,52 +124,46 @@ int librfc2874_bitstring_to_ipv6addrstruct(const char *inputstring, ipv6calc_ipv
 	ipv6addr_clearall(ipv6addrp);
 
 	/* reverse copy of string */
-	snprintf(tempstring, sizeof(tempstring) - 1, "%s", inputstring);
+	snprintf(tempstring, sizeof(tempstring), "%s", inputstring);
 	string_to_lowcase(tempstring);
 
-	if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-		fprintf(stderr, "%s: get string: %s\n", DEBUG_function_name, tempstring);
-	};
+	DEBUGPRINT_WA(DEBUG_librfc2874, "get string: %s", tempstring);
 
 	length = (unsigned int) strlen(tempstring);
 
 	/* check content */
-	retval = librfc2874_formatcheck(tempstring, resultstring);
+	retval = librfc2874_formatcheck(tempstring, resultstring, sizeof(resultstring));
 	
 	if (retval != 0) {
 		return (1);
 	}
 	
-	if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-		fprintf(stderr, "%s: format is ok: %s\n", DEBUG_function_name, tempstring);
-	};
+	DEBUGPRINT_WA(DEBUG_librfc2874, "format is ok: %s", tempstring);
 
 	index = 3; /* start value */
 	
 	while(isxdigit((int) tempstring[index])) {
-		snprintf(tempstring2, sizeof(tempstring2) - 1, "%c", tempstring[index]);
+		snprintf(tempstring2, sizeof(tempstring2), "%c", tempstring[index]);
 
-		if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-			fprintf(stderr, "%s: parse nibble: %s\n", DEBUG_function_name, tempstring2);
-		};
+		DEBUGPRINT_WA(DEBUG_librfc2874, "parse nibble: %s", tempstring2);
 		
 		/* now proceed nibbles */
 		retval = sscanf(tempstring2, "%x", &xdigit);
 
 		if (retval != 1) {
-			snprintf(resultstring, NI_MAXHOST - 1, "Nibble '%s' at position %u cannot be parsed", tempstring2, index + 1);
+			snprintf(resultstring, resultstring_length, "Nibble '%s' at position %u cannot be parsed", tempstring2, index + 1);
 			return (1);
 		};
 
 		if (xdigit > 0xf) {
-			snprintf(resultstring, NI_MAXHOST - 1, "Nibble '%s' at dot position %u is out of range", tempstring2, index + 1);
+			snprintf(resultstring, resultstring_length, "Nibble '%s' at dot position %u is out of range", tempstring2, index + 1);
 			return (1);
 		};
 
 		noctet = nibblecounter >> 1; /* divided by 2 */
 		
 		if (noctet > 15) {
-			snprintf(resultstring, NI_MAXHOST - 1, "Too many nibbles");
+			snprintf(resultstring, resultstring_length, "Too many nibbles");
 			return (1);
 		};
 
@@ -201,7 +183,7 @@ int librfc2874_bitstring_to_ipv6addrstruct(const char *inputstring, ipv6calc_ipv
 	};
 	
 	if (index > length) {
-		snprintf(resultstring, NI_MAXHOST - 1, "Unexpected end of string");
+		snprintf(resultstring, resultstring_length, "Unexpected end of string");
 		return (1);
 	};
 
@@ -210,28 +192,26 @@ int librfc2874_bitstring_to_ipv6addrstruct(const char *inputstring, ipv6calc_ipv
 		ipv6addrp->flag_prefixuse = 1;
 		ipv6addrp->prefixlength = (uint8_t) nibblecounter << 2;
 
-		if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-			fprintf(stderr, "%s: implicit prefix length: %d\n", DEBUG_function_name, ipv6addrp->prefixlength);
-		};
+		DEBUGPRINT_WA(DEBUG_librfc2874, "implicit prefix length: %d", ipv6addrp->prefixlength);
 
 		goto END_bitstring_to_ipv6addrstruct;
 	};
 	index++;
 
 	if (index > length) {
-		snprintf(resultstring, NI_MAXHOST - 1, "Unexpected end of string");
+		snprintf(resultstring, resultstring_length, "Unexpected end of string");
 		return (1);
 	};
 
 	/* proceed prefix length */
 	if (tempstring[index] == '/') {
-		snprintf(resultstring, NI_MAXHOST - 1, "Char '%c' not expected on position %u", tempstring[index], index + 1);
+		snprintf(resultstring, resultstring_length, "Char '%c' not expected on position %u", tempstring[index], index + 1);
 		return (1);
 	};
 	index++;
 
 	if (index > length) {
-		snprintf(resultstring, NI_MAXHOST - 1, "Unexpected end of string");
+		snprintf(resultstring, resultstring_length, "Unexpected end of string");
 		return (1);
 	};
 
@@ -249,39 +229,33 @@ int librfc2874_bitstring_to_ipv6addrstruct(const char *inputstring, ipv6calc_ipv
 		/* bitstring label closed */
 
 		if (endprefixlength == 0) {
-			snprintf(resultstring, NI_MAXHOST - 1, "Invalid prefix length");
+			snprintf(resultstring, resultstring_length, "Invalid prefix length");
 			return (1);
 		};
 
-		if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-			fprintf(stderr, "%s: prefix length start=%d end=%d\n", DEBUG_function_name, startprefixlength, endprefixlength);
-		};
+		DEBUGPRINT_WA(DEBUG_librfc2874, "prefix length start=%d end=%d", startprefixlength, endprefixlength);
 
 		snprintf(tempstring2, endprefixlength - startprefixlength + 2, "%s", tempstring + startprefixlength - 1);
 
-		if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-			fprintf(stderr, "%s: parse prefix length: %s\n", DEBUG_function_name, tempstring2);
-		};
+		DEBUGPRINT_WA(DEBUG_librfc2874, "parse prefix length: %s", tempstring2);
 		
 		/* now proceed nibbles */
 		retval = sscanf(tempstring2, "%u", &prefixlength);
 
 		if ( /*prefixlength < 0 || */ prefixlength > 128) {
-			snprintf(resultstring, NI_MAXHOST - 1, "Given prefix length '%u' is out of range", prefixlength);
+			snprintf(resultstring, resultstring_length, "Given prefix length '%u' is out of range", prefixlength);
 			return (1);
 		};
 		
 		ipv6addrp->flag_prefixuse = 1;
 		ipv6addrp->prefixlength = (uint8_t) prefixlength;
 
-		if ( (ipv6calc_debug & DEBUG_librfc2874) != 0 ) {
-			fprintf(stderr, "%s: explicit prefix length: %d\n", DEBUG_function_name, ipv6addrp->prefixlength);
-		};
+		DEBUGPRINT_WA(DEBUG_librfc2874, "explicit prefix length: %d", ipv6addrp->prefixlength);
 
 		goto END_bitstring_to_ipv6addrstruct;
 	};
 
-	snprintf(resultstring, NI_MAXHOST - 1, "Char '%c' not expected on position %u", tempstring[index], index + 1);
+	snprintf(resultstring, resultstring_length, "Char '%c' not expected on position %u", tempstring[index], index + 1);
 	return (1);
 
 END_bitstring_to_ipv6addrstruct:
@@ -290,7 +264,6 @@ END_bitstring_to_ipv6addrstruct:
 	retval = 0;
 	return (retval);
 };
-#undef DEBUG_function_name
 
 
 /*
@@ -299,8 +272,7 @@ END_bitstring_to_ipv6addrstruct:
  * in : string
  * ret: ==0: ok, !=0: error
  */
-#define DEBUG_function_name "librfc2874/formatcheck"
-int librfc2874_formatcheck(const char *string, char *infostring) {
+int librfc2874_formatcheck(const char *string, char *infostring, const size_t infostring_length) {
 	unsigned int length, index = 0;
 	unsigned int nibblecounter = 0, digitcounter = 0;
 
@@ -310,25 +282,25 @@ int librfc2874_formatcheck(const char *string, char *infostring) {
 
 	/* check length */
 	if (length < 5) {
-		snprintf(infostring, NI_MAXHOST - 1, "Error in given bitstring label, has less than 5 chars!");
+		snprintf(infostring, infostring_length, "Error in given bitstring label, has less than 5 chars!");
 		return (1);
 	};
 	
 	/* check start */
 	if (string[index] != '\\') {
-		snprintf(infostring, NI_MAXHOST - 1, "Char '%c' not expected on position %u", string[index], index + 1);
+		snprintf(infostring, infostring_length, "Char '%c' not expected on position %u", string[index], index + 1);
 		return (1);
 	};
 	index++;
 	
 	if (string[index] != '[') {
-		snprintf(infostring, NI_MAXHOST - 1, "Char '%c' not expected on position %u", string[index], index + 1);
+		snprintf(infostring, infostring_length, "Char '%c' not expected on position %u", string[index], index + 1);
 		return (1);
 	};
 	index++;
 	
 	if ( (char) tolower(string[index]) != 'x') {
-		snprintf(infostring, NI_MAXHOST - 1, "Char '%c' not expected on position %u", string[index], index + 1);
+		snprintf(infostring, infostring_length, "Char '%c' not expected on position %u", string[index], index + 1);
 		return (1);
 	};
 	index++;
@@ -338,7 +310,7 @@ int librfc2874_formatcheck(const char *string, char *infostring) {
 		nibblecounter++;
 
 		if (nibblecounter > 32) {
-			snprintf(infostring, NI_MAXHOST - 1, "More than 32 nibbles on position %u", index + 1);
+			snprintf(infostring, infostring_length, "More than 32 nibbles on position %u", index + 1);
 			return (1);
 		};
 
@@ -349,7 +321,7 @@ int librfc2874_formatcheck(const char *string, char *infostring) {
 	};
 	
 	if (index >= length) {
-		snprintf(infostring, NI_MAXHOST - 1, "Unexpected end of string (missing '/' or ']')");
+		snprintf(infostring, infostring_length, "Unexpected end of string (missing '/' or ']')");
 		return (1);
 	};
 
@@ -360,13 +332,13 @@ int librfc2874_formatcheck(const char *string, char *infostring) {
 
 	/* proceed prefix length */
 	if (string[index] != '/') {
-		snprintf(infostring, NI_MAXHOST - 1, "Char '%c' not expected on position %u", string[index], index + 1);
+		snprintf(infostring, infostring_length, "Char '%c' not expected on position %u", string[index], index + 1);
 		return (1);
 	};
 	index++;
 
 	if (index >= length) {
-		snprintf(infostring, NI_MAXHOST - 1, "Unexpected end of string (missing prefix length)");
+		snprintf(infostring, infostring_length, "Unexpected end of string (missing prefix length)");
 		return (1);
 	};
 	
@@ -375,7 +347,7 @@ int librfc2874_formatcheck(const char *string, char *infostring) {
 		digitcounter++;
 
 		if (digitcounter > 3) {
-			snprintf(infostring, NI_MAXHOST - 1, "More than 3 digits on position %u", index + 1);
+			snprintf(infostring, infostring_length, "More than 3 digits on position %u", index + 1);
 			return (1);
 		};
 
@@ -386,7 +358,7 @@ int librfc2874_formatcheck(const char *string, char *infostring) {
 	};
 	
 	if (index >= length) {
-		snprintf(infostring, NI_MAXHOST - 1, "Unexpected end of string (missing ']')");
+		snprintf(infostring, infostring_length, "Unexpected end of string (missing ']')");
 		return (1);
 	};
 	
@@ -395,8 +367,7 @@ int librfc2874_formatcheck(const char *string, char *infostring) {
 		return (0);
 	};
 	
-	snprintf(infostring, NI_MAXHOST - 1, "Char '%c' not expected on position %u", string[index], index + 1);
+	snprintf(infostring, infostring_length, "Char '%c' not expected on position %u", string[index], index + 1);
 
 	return (1);
 };
-#undef DEBUG_function_name
